/***********************************************************************
 *
 * MODULE NAME:    LE_gatt_server.c
 * PROJECT CODE:   CEVA Low Energy Single Mode
 * DESCRIPTION:    Implementation of the GATT Database Server.
 * MAINTAINER:     Gary Fleming
 * CREATION DATE:  Janurary 2012
 *
 *
 * LICENSE:
 *     This source code is copyright (c) 2011-2012 Ceva Inc.
 *     All rights reserved.
 *
 ***********************************************************************/
#include "sys_config.h"
#include "sys_types.h"
#include "sys_features.h"
#if (PRH_BS_CFG_SYS_LE_GATT_INCLUDED==1)
#include "le_connection.h"
#include "le_att.h"
#include "tra_queue.h"
#include "le_const.h"
#include "le_config.h"
#include "LE_gatt_server.h"
#include "lmp_types.h"
#include "hc_const.h"
#include "le_smp.h"
#include "lmp_utils.h"
#include "le_att.h"
#include "sys_mmi.h"
#include "le_cts_app.h"
#include "sys_features.h"
#include "hw_le_lc_impl.h"
#include "hw_radio_defs.h"
#include "hw_radio.h"
#include "le_l2cap.h"
#if (PRH_BS_CFG_SYS_LE_GATT_INCLUDED==1)
u_int16 GATT_reconnection_address_handle = 0x00;
static u_int16 GATTserver_DB_last_index;
static u_int16 GATTserver_DB_next_index = 0;
static u_int16 GATTserver_DB_last_handle =0;
#if (PRH_BS_CFG_SYS_LE_GAP_RECONNECTION_ADDRESS_SUPPORTED==1)
static u_int16 GATTserver_DB_Reconnection_Address_Index = 0;
u_int8 reconnection_addr_valid = 0x00;
#endif
#if (PRH_BS_CFG_SYS_LE_GAP_PRIVACY_SUPPORTED==1)
u_int16 GATTserver_DB_Peripheral_Privacy_Flag_Index = 0;
#endif
u_int16 GATTserver_Pending_Indications[GATT_SERVER_MAX_PENDING_INDICATIONS];
u_int8  GATTserver_pending_Indications_Index=0;
// GATT Server Global Paramers..
// These are global Variables which are stored in the GATT DataBase
RW_RAM t_attrib GATTserver_DB[MAX_GATT_SERVER_NUM_ENTRIES];
u_int16 GATTserver_Handle_in_Error=0;
u_int8 GATTprivacy_Flags = 0;
u_int8 _GATTserver_Check_Space_Available(u_int16 GATTserver_DB_next_index);
u_int16 _GATTserver_Find_End_Group_Handle(u_int16 current_index);
u_int8 GATTserver_Check_Is_Service_Authorised(void);
t_GATT_error GATTserver_Check_Encryption_Key_Size(u_int8 permissions);
t_GATT_error GATTserver_Check_Permissions(t_attrib* p_current_attrib,u_int8 action);
u_int8 GATTserver_Find_DB_Index(u_int16 start_handle,u_int16 end_handle,u_int16* p_index);
t_error GATTserver_Init(void)
{
    Gatt_Set_MTU_Size(23);
    GATTserver_DB_next_index = 0;
    GATTserver_DB_last_handle =0;
#if (PRH_BS_CFG_SYS_LE_GAP_RECONNECTION_ADDRESS_SUPPORTED==1)
    reconnection_addr_valid = 0x00;
#endif
    App_Setup_GAP_GATT_DB();
    App_Setup_GATT_GATT_DB();
    App_Setup_DEV_INFO_GATT_DB();
    // App_Setup_BATTERY_SERVICE_GATT_DB();
    GATTserver_DB_last_handle=App_Setup_HID_GATT_DB();
    GATTserver_DB_last_handle = GATTserver_DB_last_handle-1;
    GATTserver_DB_last_index = GATTserver_DB_next_index-1;
    return NO_ERROR;
}
/*****************************************************************************************************
 * _GATTserver_Add_Characteristic_Declaration
 *
 * Adds a 16 bit characteristic declaration to the Server DB
 *****************************************************************************************************/
u_int8 _GATTserver_Add_Characteristic_Declaration(u_int16 handle,u_int16 char_UUID,u_int8 properties)
{
    t_attrib* p_current_attrib = &GATTserver_DB[GATTserver_DB_next_index];
    if (_GATTserver_Check_Space_Available(GATTserver_DB_next_index))
    {
        p_current_attrib->attrib_handle = handle;
        p_current_attrib->attrib_len = 0x02;
        p_current_attrib->attrib_UUID.UUID_val = GATT_ATT_TYPE_CHARACTERISTIC;
        p_current_attrib->permissions = GATT_PERMISSION_READ; // Read only ?
        p_current_attrib->attrib_value.char_declaration.UUID_len = 0x02;
        p_current_attrib->attrib_value.char_declaration.char_UUID.UUID_val = char_UUID;
        p_current_attrib->attrib_value.char_declaration.properties = properties;
        p_current_attrib->attrib_value.char_declaration.char_value_handle = handle+1;
        GATTserver_DB_next_index++;
        return NO_ERROR;
    }
    else
    {
        return UNSPECIFIED_ERROR;
    }
}
/*****************************************************************************************************
 * _GATTserver_Add_16ByteUUID_Characteristic_Declaration
 *
 * Adds a 128 bit characteristic declaration to the Server DB
 *****************************************************************************************************/
u_int8 _GATTserver_Add_16ByteUUID_Characteristic_Declaration(u_int16 handle, u_int8* p_UUID,u_int8 properties)
{
#if (PRH_BS_CFG_SYS_LE_SERVER_SUPPORTS_128_BIT_UUIDS==1)
    t_attrib* p_current_attrib = &GATTserver_DB[GATTserver_DB_next_index];
    if (_GATTserver_Check_Space_Available(GATTserver_DB_next_index))
    {
        p_current_attrib->attrib_handle = handle;
        p_current_attrib->attrib_len = 0x02;
        p_current_attrib->attrib_UUID.UUID_val = GATT_ATT_TYPE_CHARACTERISTIC;
        p_current_attrib->permissions = GATT_PERMISSION_READ;
        p_current_attrib->attrib_value.char_declaration.UUID_len = 0x10;
        p_current_attrib->attrib_value.char_declaration.char_UUID.p_UUID = p_UUID;
        p_current_attrib->attrib_value.char_declaration.properties = properties;
        p_current_attrib->attrib_value.char_declaration.char_value_handle = handle + 1;
        GATTserver_DB_next_index++;
        return NO_ERROR;
    }
    else
#endif
        return UNSPECIFIED_ERROR;
}
/*****************************************************************************************************
 * _GATTserver_Add_Service
 *
 * Adds a Service Definition to the Service DB
 *****************************************************************************************************/
u_int8 _GATTserver_Add_Service(u_int8 service_type,u_int16 handle,u_int8* p_service_UUID,u_int16 service_UUID)
{
    t_attrib* p_current_attrib = &GATTserver_DB[GATTserver_DB_next_index];
    if(_GATTserver_Check_Space_Available(GATTserver_DB_next_index))
    {
        p_current_attrib->attrib_handle = handle;
        p_current_attrib->permissions = GATT_PERMISSION_READ;
        if (service_type == PRIMARY_SERVICE_16BIT)
        {
            p_current_attrib->attrib_UUID.UUID_val = GATT_ATT_TYPE_PRIMARY_SERVICE;
        }
        else if (service_type == SECONDARY_SERVICE_16BIT)
        {
            p_current_attrib->attrib_UUID.UUID_val = GATT_ATT_TYPE_SECONDARY_SERVICE;
        }
#if (PRH_BS_CFG_SYS_LE_SERVER_SUPPORTS_128_BIT_UUIDS==1)
        else if (service_type == PRIMARY_SERVICE_128BIT)
        {
            p_current_attrib->attrib_UUID.UUID_val = GATT_ATT_TYPE_PRIMARY_SERVICE;
        }
        else if (service_type == SECONDARY_SERVICE_128BIT)
        {
            p_current_attrib->attrib_UUID.UUID_val = GATT_ATT_TYPE_SECONDARY_SERVICE;
        }
        if ((service_type == PRIMARY_SERVICE_16BIT) || (service_type == SECONDARY_SERVICE_16BIT))
        {
            p_current_attrib->attrib_value.service.service_UUID_len = 0x02;
            p_current_attrib->attrib_value.service.service_UUID.UUID_val = service_UUID;
        }
        else
        {
            p_current_attrib->attrib_value.service.service_UUID_len = 0x10;
            p_current_attrib->attrib_value.service.service_UUID.p_UUID = p_service_UUID;
        }
#else
        p_current_attrib->attrib_value.service.service_UUID_len = 0x02;
        p_current_attrib->attrib_value.service.service_UUID.UUID_val = service_UUID;
#endif
#if 1 // UPF 44 Added to overcome problems with Find Information Request - TI and CSR
        p_current_attrib->attrib_len = 0x02;
#endif
        GATTserver_DB_next_index++;
        return NO_ERROR;
    }
    else
    {
        return UNSPECIFIED_ERROR;
    }
}
/*****************************************************************************************************
 * _GATTserver_Add_Included_Service
 *
 * Adds an included service definition to the Service DB
 *****************************************************************************************************/
u_int8 _GATTserver_Add_Included_Service(u_int16 handle, u_int16 start_handle,u_int16 end_handle,u_int16 service_UUID)
{
#if (PRH_BS_CFG_SYS_LE_SERVER_SUPPORTS_INCLUDED_SERVICES==1)
    t_attrib* p_current_attrib = &GATTserver_DB[GATTserver_DB_next_index];
    _GATTserver_Check_Space_Available(GATTserver_DB_next_index);
    p_current_attrib->attrib_handle = handle;
    p_current_attrib->attrib_len = 0x02;
    p_current_attrib->attrib_UUID.UUID_val = GATT_ATT_TYPE_INCLUDE;
    p_current_attrib->permissions = GATT_PERMISSION_READ; // All included services are Read Only with No Authentication/Authorisation required
    p_current_attrib->attrib_value.include_service.start_handle = start_handle;
    p_current_attrib->attrib_value.include_service.end_handle = end_handle;
    p_current_attrib->attrib_value.include_service.service_UUID_len = 0x02;
    p_current_attrib->attrib_value.include_service.service_UUID.UUID_val = service_UUID;
    GATTserver_DB_next_index++;
    return 0;
#else
    return UNSPECIFIED_ERROR;
#endif
}
/*****************************************************************************************************
 * _GATTserver_Add_Characteristic_Value
 *
 * Adds a characteristic value to the Service DB for a 16 Bit Chararacteristic
 *****************************************************************************************************/
u_int8 _GATTserver_Add_Characteristic_Value(u_int16 handle,u_int16 char_UUID,u_int8 local_notify,u_int8 permissions,u_int8 val_len,u_int8* p_value)
{
    t_attrib* p_current_attrib = &GATTserver_DB[GATTserver_DB_next_index];
#if (PRH_BS_CFG_SYS_LE_GAP_PRIVACY_SUPPORTED==1) // ????
    if (char_UUID == PERIPHERAL_PRIVACY_FLAG)
    {
        GATTserver_DB_Peripheral_Privacy_Flag_Index = GATTserver_DB_next_index;
    }
#endif
    p_current_attrib->attrib_value.value.p_value = p_value;
#if (PRH_BS_CFG_SYS_LE_GAP_RECONNECTION_ADDRESS_SUPPORTED==1)
    if (char_UUID == RECONNECTION_ADDRESS)
    {
        GATTserver_DB_Reconnection_Address_Index = GATTserver_DB_next_index;
    }
#endif
    p_current_attrib->attrib_handle = handle;
    p_current_attrib->attrib_len = 0x02;
    p_current_attrib->attrib_UUID.UUID_val = char_UUID;
    p_current_attrib->permissions = permissions;
    p_current_attrib->attrib_value.value.local_notification = local_notify;
    p_current_attrib->attrib_value.value.val_len = val_len;
    p_current_attrib->attrib_value.value.max_len = val_len;
    GATTserver_DB_next_index++;
    return 0;
}
/*****************************************************************************************************
 * _GATTserver_Add_16ByteUUID_Characteristic_Value
 *
 * Adds a characteristic value to the Service DB for a 128 Bit Chararacteristic
 *****************************************************************************************************/
u_int8 _GATTserver_Add_16ByteUUID_Characteristic_Value(u_int16 handle,u_int8* char_UUID,u_int8 local_notify,u_int8 permissions,u_int8 val_len,u_int8* p_value)
{
#if (PRH_BS_CFG_SYS_LE_SERVER_SUPPORTS_128_BIT_UUIDS==1)
    t_attrib* p_current_attrib = &GATTserver_DB[GATTserver_DB_next_index];
    // Device Name Characteristic Value
    _GATTserver_Check_Space_Available(GATTserver_DB_next_index);
    p_current_attrib->attrib_handle = handle;
    p_current_attrib->attrib_len = 0x10;
    p_current_attrib->attrib_UUID.p_UUID = char_UUID;
    p_current_attrib->permissions = permissions;
    p_current_attrib->attrib_value.value.local_notification = local_notify;
    p_current_attrib->attrib_value.value.val_len = val_len;
    p_current_attrib->attrib_value.value.max_len = val_len;
#if 0
    p_current_attrib->attrib_value.value.p_value = _GATTserver_add_value_to_val_array(val_len,p_value);
#else
    p_current_attrib->attrib_value.value.p_value = p_value;
#endif
    GATTserver_DB_next_index++;
#endif
    return 0;
}
/*****************************************************************************************************
 * _GATTserver_Add_Characteristic_Propietrary_Descriptor
 *
 * Adds a propietrary characteristic descriptor to the Service DB.
 *****************************************************************************************************/
u_int8 _GATTserver_Add_Characteristic_Propietrary_Descriptor(u_int16 handle,u_int8 UUID_len, u_int8* p_UUID, u_int8 permissions,u_int8* p_value)
{
#if (PRH_BS_CFG_SYS_LE_SERVER_SUPPORTS_128_BIT_UUIDS==1)
    t_attrib* p_current_attrib = &GATTserver_DB[GATTserver_DB_next_index];
    _GATTserver_Check_Space_Available(GATTserver_DB_next_index);
    p_current_attrib->attrib_handle = handle;
    p_current_attrib->attrib_len = 0x10;
    p_current_attrib->attrib_UUID.p_UUID = p_UUID ;
    p_current_attrib->permissions = permissions;
    p_current_attrib->attrib_value.value.val_len = 1;
    p_current_attrib->attrib_value.value.max_len = 1;
    p_current_attrib->attrib_value.value.p_value = p_value;
    GATTserver_DB_next_index++;
#endif
    return 0;
}
/*
 * The Client Characteristic Configuration descriptor value shall be persistent
 * across connections for bonded devices. The Client Characteristic Configuration
 * descriptor value shall be set to the default value at each connection with
 * non-bonded devices.The characteristic descriptor value is a bit field. When a
 * bit is set, that action shall be enabled, otherwise it will not be used. The Client
 * Characteristic Configuration descriptor may occur in any position within the
 * characteristic definition after the Characteristic Value. Only one Client Characteristic
 * Configuration declaration shall exist in a characteristic definition.
 */
/*****************************************************************************************************
 * _GATTserver_Add_Char_Descriptor
 *
 * Adds a characteristic descriptor to the Service DB.
 *****************************************************************************************************/
u_int8 _GATTserver_Add_Char_Descriptor(u_int16 handle,u_int16 uuid,u_int8 permission,u_int8 val_len,u_int8* p_value)
{
    t_attrib* p_current_attrib = &GATTserver_DB[GATTserver_DB_next_index];
    if (_GATTserver_Check_Space_Available(GATTserver_DB_next_index))
    {
        p_current_attrib->attrib_handle = handle;
        p_current_attrib->attrib_len = 0x02;
        p_current_attrib->attrib_UUID.UUID_val = uuid;
        p_current_attrib->permissions = permission;
        p_current_attrib->attrib_value.value.val_len = val_len;
        p_current_attrib->attrib_value.value.max_len = val_len;
        p_current_attrib->attrib_value.value.p_value = p_value;
        GATTserver_DB_next_index++;
        return NO_ERROR;
    }
    else
    {
        return UNSPECIFIED_ERROR;
    }
}
/*
 * GATT Functions to search the Server DB.
 */
/*****************************************************************************************************
 * GATTserver_Read_By_Group_Type
 * This function is used to discover all the primary services on a server, within a given handle range.
 *
 * This function is only used for primary service discovery. It is only ever dealing with UUIDs for primary services.
 *
 * INPUTS
 * u_int16  max_result_len : This is the maximum length of data which can be returned.
 * u_int16  start_handle   : The start handle  for the range to be searched
 * u_int16  end_handle     : The end handle  for the range to be searched
 *
 * u_int16  attrib_UUID   : PRIMARY_SERVICE_TYPE | SECONDARY_SERVICE_TYPE
 *
 * OUTPUTS
 * u_int8* p_result       :- A pointer to a list of start,end handle and services UUIDs corresponding to each service matching
 *                              attrib_UUID.
 * u_int8* p_result_len   :- A pointer to the total length of valid data in the result field ( pointed to by p_result ).
 *
 *****************************************************************************************************/
u_int8 GATTserver_Read_By_Group_Type(u_int8 max_result_len,u_int16 start_handle,u_int16 end_handle,u_int16 attrib_UUID,
                                     u_int8* p_result, u_int8* p_result_len )
{
    u_int16 i=0;
    u_int8* p_payload = p_result;
    u_int8 status;
    extern t_ATT_config ATT_config;
    *p_result_len = 0x00;
    status = GATTserver_Find_DB_Index(start_handle,end_handle,&i);
    if (status != NO_ERROR)
    {
        if (status == GATT_ERROR_INVALID_HANDLE )
        {
            status = GATT_ERROR_ATTRIBUTE_NOT_FOUND;
        }
        return status;
    }
    // i now is the index to the start handle in the Server DB
    while ((i<=GATTserver_DB_last_index) && (GATTserver_DB[i].attrib_handle <= end_handle) && (((*p_result_len)+6) < max_result_len) )
    {
        t_attrib* p_current_attrib = &GATTserver_DB[i];
        // if the attrib_UUID match
        if ((p_current_attrib->attrib_UUID.UUID_val == attrib_UUID) && (p_current_attrib->permissions & GATT_PERMISSION_READ))
        {
            if(((*p_result_len)+4+p_current_attrib->attrib_value.service.service_UUID_len) > ATT_config.MTU_LEN)
            {
                break;
            }
            LMutils_Set_Uint16(p_payload, p_current_attrib->attrib_handle );
            if(_GATTserver_Find_End_Group_Handle(i) == (GATTserver_DB_last_index+1))
            {
                LMutils_Set_Uint16(p_payload+2, 0xFFFF );
            }
            else
            {
                LMutils_Set_Uint16(p_payload+2, _GATTserver_Find_End_Group_Handle(i) );
            }
            if (p_current_attrib->attrib_value.service.service_UUID_len == 0x02)
            {
                LMutils_Set_Uint16(p_payload+4, p_current_attrib->attrib_value.service.service_UUID.UUID_val);
                p_payload+=6;
                *p_result_len+=6;
            }
            if(p_current_attrib->attrib_value.service.service_UUID_len == 0x10)
            {
                LMutils_Set_U128bits(p_payload+4, p_current_attrib->attrib_value.service.service_UUID.p_UUID);
                p_payload+=20;
                *p_result_len+=20;
            }
        }
        i++;
    }
    if (*p_result_len == 0x00)
    {
        return GATT_ERROR_ATTRIBUTE_NOT_FOUND;
    }
    return 0;
}
/*****************************************************************************************************
 * GATTserver_Find_DB_Index
 *
 * Simple function which finds the DB index for a given handle.
 *
 *****************************************************************************************************/
u_int8 GATTserver_Find_DB_Index(u_int16 start_handle,u_int16 end_handle,u_int16* p_index)
{
    u_int16 i=0;
    if((start_handle > end_handle) || (start_handle == 0x0000) )
    {
        return GATT_ERROR_INVALID_HANDLE;
    }
    if(start_handle > GATTserver_DB_last_handle)
    {
        return GATT_ERROR_ATTRIBUTE_NOT_FOUND;
    }
    while ((i<=GATTserver_DB_last_index) && (GATTserver_DB[i].attrib_handle < start_handle))
    {
        i++;
    }
    *p_index = i;
    return NO_ERROR;
}
/*****************************************************************************************************
 * GATTserver_Find_By_Type_And_Value
 *
 * This function supports the Clients Discover Primary (or Secondary) Services By Service UUID
 *
 * The service may exist multiple times on a server. The primary service being discovered is
 * identified by the service UUID.
 * INPUTS
 * u_int16  max_result_len : This is the maximum length of data which can be returned.
 * u_int16  start_handle   : The start handle  for the range to be searched
 * u_int16  end_handle     : The end handle  for the range to be searched
 *
 * u_int16  attrib_type   : PRIMARY_SERVICE_TYPE | SECONDARY_SERVICE_TYPE
 *
 * u_int16  attrib_value  : The UUID value for the Service
 *
 * OUTPUTS
 * u_int8* p_result       :- A pointer to a list of start and end handle pairs corresponding to each service matching
 *                              attrib_type and value.
 * u_int8* p_result_len   :- A pointer the total length of valid data in the result field ( pointed to by p_result ).
 *
 *****************************************************************************************************/
u_int8 GATTserver_Find_By_Type_And_Value(u_int16 max_result_len,u_int16 start_handle,u_int16 end_handle,
        u_int16 attrib_type,u_int16 attrib_value,u_int8* p_result,u_int8* p_result_len)
{
    u_int16 i=0;
    u_int8 result_len = 0;
    u_int8* p_payload = p_result;
    u_int8 status;
    *p_result_len = 0x00;
    status = GATTserver_Find_DB_Index(start_handle,end_handle,&i);
    if (status != NO_ERROR)
    {
        return status;
    }
    // i now is the index to the start handle in the Server DB
    while ((GATTserver_DB[i].attrib_handle <= end_handle) && ((result_len+6) < max_result_len) && (i<=GATTserver_DB_last_index))
    {
        t_attrib* p_current_attrib = &GATTserver_DB[i];
        // if the attrib_UUID match
        if ((p_current_attrib->attrib_UUID.UUID_val == attrib_type) && (p_current_attrib->permissions & GATT_PERMISSION_READ) &&
                (p_current_attrib->attrib_value.service.service_UUID.UUID_val == attrib_value))
        {
            // Matching entry and Readable
            // Check if authentication required
            status = GATTserver_Check_Permissions(p_current_attrib, GATT_READ);
            if (status != NO_ERROR)
            {
                return status;
            }
            LMutils_Set_Uint16(p_payload, p_current_attrib->attrib_handle );
            LMutils_Set_Uint16(p_payload+2, _GATTserver_Find_End_Group_Handle(i) );
            p_payload+=4;
            *p_result_len+=4;
        }
        i++;
    }
    if (*p_result_len == 0x00)
    {
        return GATT_ERROR_ATTRIBUTE_NOT_FOUND;
    }
    return NO_ERROR;
}
/*****************************************************************************************************
 * GATTserver_Find_Included_Services
 *
 * This function is used to find include service declarations within a service definition on a server. The service specified
 * is identified by the service handle range..
 *
 * The Starting Handle shall be set to starting handle of the specified service and the Ending Handle shall be set to the
 * ending handle of the specified service.
 *
 * This function supports the discovery of both 16 Bit and 128 Bit UUIDs.
 *
 * Parameters :
 *     u_int16 max_result_len :- This is the maximum length of data which can be returned.
 *  u_int16 start_handle   :- The Starting handle of a service.
 *  u_int16 end_handle     :- The end handle of the  service.
 *  u_int8* p_result       :- A pointer to a list of Attribute Handle and Attribute Value pairs corresponding to the included
 *                            services in the service definition
 *  u_int8* p_result_len   :- A pointer the total length of valid data in the result field ( pointed to by p_result ).
 *
 *****************************************************************************************************/
u_int8 GATTserver_Find_Included_Services(u_int16 max_result_len,u_int16 start_handle,u_int16 end_handle,u_int8* p_result,u_int8* p_result_len)
{
#if(PRH_BS_CFG_SYS_LE_SERVER_SUPPORTS_INCLUDED_SERVICES==1)
    u_int16 i=0;
    u_int8* p_payload = p_result;
    u_int8 status;
    *p_result_len = 0x00;
    status = GATTserver_Find_DB_Index(start_handle,end_handle,&i);
    if (status != NO_ERROR)
    {
        return status;
    }
    // i now is the index to the start handle in the Server DB
    while ((GATTserver_DB[i].attrib_handle <= end_handle) && ((*p_result_len+8) < max_result_len) && (i<=GATTserver_DB_last_index))
    {
        t_attrib* p_current_attrib = &GATTserver_DB[i];
        GATTserver_Handle_in_Error = GATTserver_DB[i].attrib_handle;
        // if the attrib_UUID match
        if ((p_current_attrib->attrib_UUID.UUID_val == GATT_ATT_TYPE_INCLUDE) && (p_current_attrib->permissions & GATT_PERMISSION_READ))
        {
            LMutils_Set_Uint16(p_payload, p_current_attrib->attrib_handle );
            LMutils_Set_Uint16(p_payload+2, p_current_attrib->attrib_value.include_service.start_handle );
            LMutils_Set_Uint16(p_payload+4, p_current_attrib->attrib_value.include_service.end_handle );
            if (p_current_attrib->attrib_len == 02)
            {
                LMutils_Set_Uint16(p_payload+6, p_current_attrib->attrib_value.include_service.service_UUID.UUID_val);
                p_payload+=8;
                *p_result_len+=8;
            }
#if (PRH_BS_CFG_SYS_LE_SERVER_SUPPORTS_128_BIT_UUIDS == 1)
            else
            {
                p_payload+=6;
                *p_result_len+=6;
            }
#endif
        }
        i++;
    }
    if (*p_result_len == 0x00)
    {
        return GATT_ERROR_ATTRIBUTE_NOT_FOUND;
    }
    return NO_ERROR;
#else
    return GATT_ERROR_ATTRIBUTE_NOT_FOUND;
#endif
}
/*****************************************************************************************************
 * GATTserver_Discover_All_Characteristics_Of_A_Service
 *
 * This function is used to support Characteristic Discovery. Both sub-procedures are supported by this function on the server.
 * The difference between the Discover_All_Characteristics_Of_A_Service and Discover_Characteristics_By_UUID exists on the
 * Client side - no differences on the server side.
 *
 * This function supports the discovery of both 16 Bit and 128 Bit UUIDs.
 *
 * Parameters :
 *     u_int16 max_result_len :- This is the maximum length of data which can be returned.
 *  u_int16 start_handle   :- The Starting handle of a service.
 *  u_int16 end_handle     :- The end handle of the specified service.
 *  u_int8* p_result       :- A pointer to a list of Attribute Handle and Attribute Value pairs corresponding to the characteristics
 *                            in the service definition. The Attribute Handle is the handle for the characteristic
 *                            declaration. The Attribute Value is the Characteristic Properties, Characteristic Value Handle
 *                            and Characteristic UUID.
 *  u_int8* p_result_len   :- A pointer the total length of valid data in the result field ( pointed to by p_result ).
 *
 *****************************************************************************************************/
u_int8 GATTserver_Discover_All_Characteristics_Of_A_Service(u_int16 max_result_len,u_int16 start_handle,u_int16 end_handle,u_int8* p_result,u_int8* p_result_len,u_int8* p_attrib_val_len)
{
    u_int16 i=0;
    u_int8 attrib_val_len = 0x00;
    u_int8* p_payload = p_result;
    u_int8 status;
    *p_result_len = 0x00;
    GATTserver_Handle_in_Error = start_handle;
    status = GATTserver_Find_DB_Index(start_handle,end_handle,&i);
    if (status != NO_ERROR)
    {
        return status;
    }
    // i now is the index to the start handle in the Server DB
    while ((GATTserver_DB[i].attrib_handle <= end_handle) && ((*p_result_len+*p_attrib_val_len) <= (max_result_len-7)) && (i<=GATTserver_DB_last_index))
    {
        t_attrib* p_current_attrib = &GATTserver_DB[i];
        // if the attrib_UUID match
        if (p_current_attrib->attrib_UUID.UUID_val == GATT_ATT_TYPE_CHARACTERISTIC)
        {
            // All Characterisic Declarations are Readable - without Authent/Author
            // See - Section 3.3.1
            // 3.3.1 Characteristic Declaration
            // "A characteristic declaration is an Attribute with the Attribute Type set to the
            // UUID for Characteristic?and Attribute Value set to the Characteristic Properties,
            // Characteristic Value Attribute Handle and Characteristic UUID. The Attribute
            // Permissions shall be readable and not require authentication or
            // authorization."
            LMutils_Set_Uint16(p_payload,p_current_attrib->attrib_handle);
            p_payload[2] = p_current_attrib->attrib_value.char_declaration.properties;
            LMutils_Set_Uint16(p_payload+3,p_current_attrib->attrib_value.char_declaration.char_value_handle);
            if ((p_current_attrib->attrib_value.char_declaration.UUID_len == 0x02) &&
                    (attrib_val_len != 21))
            {
                if (attrib_val_len==0x00) // not_determined yet
                {
                    attrib_val_len = 7;
                }
                LMutils_Set_Uint16(p_payload+5,p_current_attrib->attrib_value.char_declaration.char_UUID.UUID_val);
            }
#if (PRH_BS_CFG_SYS_LE_SERVER_SUPPORTS_128_BIT_UUIDS == 1)
            else if ((p_current_attrib->attrib_value.char_declaration.UUID_len == 0x10 ) && ((*p_result_len+20) < max_result_len) &&
                     (attrib_val_len != 7))
            {
                u_int8 j;
                if (attrib_val_len==0x00) // not_determined yet
                {
                    attrib_val_len = 21;
                }
                for(j=0; j<16; j++)
                {
                    p_payload[j+5] = p_current_attrib->attrib_value.char_declaration.char_UUID.p_UUID[j];
                }
            }
            else
            {
                break;
            }
#endif
            p_payload+= attrib_val_len;
            *p_result_len+= attrib_val_len;
        }
        i++;
    }
    *p_attrib_val_len = attrib_val_len;
    if (*p_result_len == 0x00)
    {
        return GATT_ERROR_ATTRIBUTE_NOT_FOUND;
    }
    return NO_ERROR;
}
/*****************************************************************************************************
 * GATTserver_Find_Descriptor_Information
 *
 * This function is used to discover all the descriptors for a characteristic. The characteristic is identified by the
 * the handle range.
 *
 * This function supports the discovery of both 16 Bit and 128 Bit UUIDs.
 *
 * Parameters :
 * INPUTS
 *     u_int16 max_result_len :- This is the maximum length of data which can be returned.
 *  u_int16 start_handle   :- The Starting handle of a characteristic + 1.
 *  u_int16 end_handle     :- The end handle of the characteristic.
 * OUTPUTS
 *  u_int8* p_result       :- A pointer to a list of Attribute Handle and Attribute Value pairs corresponding to the
 *                            characteristic descriptors in the characteristic definition. The Attribute Handle is the
 *                            handle for the characteristic descriptor declaration. The Attribute Value is the
 *                            Characteristic Descriptor UUID.
 *
 *  u_int8* p_result_len   :- A pointer the total length of valid data in the result field ( pointed to by p_result ).
 *
 *  u_int8* p_format       :- Is a pointer to a variable indicating the format of the data in the result field (p_result).
 *                            If *p_format = 0x01, then only 16 Bit UUIDs are used in the result field.
 *                            If *p_format = 0x02, then only 128 Bit UUIDs are used in the result field.
 *****************************************************************************************************/
u_int8 GATTserver_Find_Descriptor_Information(u_int16 max_result_len,u_int16 start_handle,u_int16 end_handle,u_int8* p_result,u_int8* p_result_len,u_int8* p_format)
{
    u_int16 i=0;
    u_int8 result_len = 0;
    u_int8* p_payload = p_result;
    u_int8 status;
    u_int8 attrib_found_len=0;
    status = GATTserver_Find_DB_Index(start_handle,end_handle,&i);
    if(status == GATT_ERROR_INVALID_HANDLE)
    {
        status = GATT_ERROR_ATTRIBUTE_NOT_FOUND;
    }
    if (status != NO_ERROR)
    {
        return status;
    }
    while ((GATTserver_DB[i].attrib_handle <= end_handle) && (i<=GATTserver_DB_last_index))
    {
        t_attrib* p_current_attrib = &GATTserver_DB[i];
        {
            /* The server shall not respond to the Find Information Request with an Error
             * Response with the Insufficient Authentication? Insufficient Authorization?
             * Insufficient Encryption Key Size?or Application Error?error code.
             */
            if (attrib_found_len != 0)
            {
                if ((attrib_found_len != p_current_attrib->attrib_len) ||
                        (!(result_len+p_current_attrib->attrib_len+2) <= max_result_len))
                {
                    // Mismatch in lengths - so end search.
                    return NO_ERROR;
                }
            }
            else
            {
                // First Attrib Found
                attrib_found_len = p_current_attrib->attrib_len;
            }
            LMutils_Set_Uint16(p_payload,p_current_attrib->attrib_handle);
            if (attrib_found_len==0x02)
            {
                *p_format = 0x01;
                LMutils_Set_Uint16(p_payload+2,p_current_attrib->attrib_UUID.UUID_val);
            }
            else if (attrib_found_len==0x10)
            {
                u_int8 j;
                *p_format = 0x02;
                for (j=0; j<attrib_found_len; j++)
                {
                    p_payload[j+2] = p_current_attrib->attrib_UUID.p_UUID[j];
                }
            }
            else
            {
                // This is important - required for PTS 4.5.3 GAR_SR_BV06.
                return GATT_ERROR_ATTRIBUTE_NOT_FOUND;
            }
            p_payload+=attrib_found_len+2;
            result_len += attrib_found_len+2;
            *p_result_len = result_len;
        }
        i++;
    }
    if (*p_result_len == 0x00)
    {
        return GATT_ERROR_ATTRIBUTE_NOT_FOUND;
    }
    return NO_ERROR;
}
/*****************************************************************************************************
 * GATTserver_Read_Characteristic_Value
 *
 * This function is used to read the value stored at a given attribute handle. This function can be used to read either
 * a characteristic value or a characteristic descriptor.
 *
 * Parameters :
 * INPUTS
 *     u_int16 max_result_len :- This is the maximum length of data which can be returned.
 *  u_int16 att_handle     :- The handle for the characteristic value to be read.
 *
 * OUTPUTS
 *  u_int8* p_result       :- The result field. A pointer to a characteristic or characteristic descriptor value.
 *
 *
 *  u_int8* p_result_len   :- A pointer the total length of valid data in the result field ( pointed to by p_result ).
 *
 *****************************************************************************************************/
u_int8 GATTserver_Read_Characteristic_Value(u_int16 max_result_len,u_int16 att_handle, u_int8* p_result,u_int8* p_result_len)
{
    u_int16 i = 0;
    u_int16 j = 0;
    t_attrib* p_current_attrib;
    t_error status;
    u_int16  UUID;
    // Find the Attribute Value Handle
    if (att_handle > GATTserver_DB_last_handle)
    {
        return GATT_ERROR_ATTRIBUTE_NOT_FOUND;
    }
    while ((GATTserver_DB[i].attrib_handle != att_handle) && (i<=GATTserver_DB_last_index))
    {
        i++;
    }
    if (GATTserver_DB[i].attrib_handle != att_handle)
    {
        return GATT_ERROR_INVALID_HANDLE;
    }
    // Now we have found the Attrib Value - 'i' is the index for it.
    p_current_attrib = &GATTserver_DB[i];
    /*
     * Check that this is the UUID for a characteristic or or characteristic descriptor.
     * Basically check it is not the UUID for a Service, Char Declaration,
     */
    status = ( t_error )GATTserver_Check_Permissions(p_current_attrib, GATT_READ);
    if (status != NO_ERROR)
    {
        return status;
    }
    if (p_current_attrib->attrib_UUID.UUID_val)
    {
        UUID = p_current_attrib->attrib_UUID.UUID_val;
#if (PRH_BS_CFG_SYS_TESTING_AGAINST_PTS4_5!=1)
        // Check is UUID is Primary Service, Secondary Service, Include Definition or Characteristic Declaration
        if ((UUID >= 0x2800) && (UUID <= 0x2803))
        {
            return GATT_ERROR_INVALID_HANDLE;
        }
#endif
    }
    {
        // Dont Know if this is a Read Value for a Characteristic Value or a Characteristic Descriptor ..
        // Only know from the Handle Which Type it is...
        u_int8* p_val = p_current_attrib->attrib_value.value.p_value;
        u_int8 length = p_current_attrib->attrib_value.value.val_len;
        if (length > max_result_len)
        {
            length = max_result_len;
        }
        for (j=0; j<length; j++)
        {
            p_result[j] = p_val[j];
        }
        *p_result_len = length;
    }
    return 0;
}
/*****************************************************************************************************
 * GATTserver_Read_Long_Characteristic_Value_Offset
 * [ Note can be optimised to include the GATTserver_Read_Characteristic_Value function also ]
 *
 * This function is used to read a long value stored at a given attribute handle. This function can be used to read
 * a characteristic value.
 *
 * Parameters :
 * INPUTS
 *     u_int16 max_result_len :- This is the maximum length of data which can be returned.
 *  u_int16 att_handle     :- The handle for the characteristic value to be read.
 *  u_int16 offset         :- The offset into the attribute value of the first byte to be read.
 *
 * OUTPUTS
 *  u_int8* p_result       :- The result field. A pointer to a characteristic or characteristic descriptor value.
 *
 *
 *  u_int8* p_result_len   :- A pointer the total length of valid data in the result field ( pointed to by p_result ).
 *
 *****************************************************************************************************/
u_int8 GATTserver_Read_Long_Characteristic_Value_Offset(u_int16 max_result_len,u_int16 att_handle, u_int16 offset, u_int8* p_result,u_int8* p_result_len)
{
    u_int8 i = 2;
    u_int8 j;
    t_attrib* p_current_attrib;
    t_error status;
    // Find the Attribute Value Handle
    if (att_handle > GATTserver_DB_last_handle)
    {
        return GATT_ERROR_ATTRIBUTE_NOT_FOUND;
    }
    while ((GATTserver_DB[i].attrib_handle != att_handle) && (i<=GATTserver_DB_last_index))
    {
        i++;
    }
    if (GATTserver_DB[i].attrib_handle != att_handle)
    {
        return GATT_ERROR_INVALID_HANDLE;
    }
    // Now we have found the Attrib Value - 'i' is the index for it.
    p_current_attrib = &GATTserver_DB[i];
    // Check the permissions
    if ((p_current_attrib->attrib_UUID.UUID_val >= 0x2800) && (p_current_attrib->attrib_UUID.UUID_val <= 0x2803))
    {
        return GATT_ERROR_INVALID_HANDLE;
    }
    status = (t_error) GATTserver_Check_Permissions(p_current_attrib, GATT_READ);
    if (status != NO_ERROR)
    {
        return status;
    }
    // Now get the pointer to the Attrib value and check attrib length.
    {
        extern t_ATT_config ATT_config;
        u_int8* p_val = p_current_attrib->attrib_value.value.p_value;
        u_int8 length = p_current_attrib->attrib_value.value.max_len;
        if (length <= (ATT_config.MTU_LEN-1))
        {
            return LE_ATT_ATTRIBUTE_NOT_LONG;
        }
        // Was bug here " >= "..
        // Spec says that if the offset == length the device returns a Read_Blob_Response with
        // zero payload.
        if (offset > length)
        {
            return GATT_ERROR_INVALID_OFFSET;
        }
        if ((length - offset) > max_result_len)
        {
            length = max_result_len;
        }
        else
        {
            length = (length - offset);
        }
        for (j=0; j<length; j++)
        {
            p_result[j] = p_val[j+offset];
        }
        *p_result_len = length;
    }
    return 0;
}
/*****************************************************************************************************
 * GATTserver_Read_Characteristic_Value_By_UUID
 * [ Note can be optimised to include the GATTserver_Read_Characteristic_Value function also ]
 *
 *  This function is used to read a Characteristic Value from a server when the client only knows the characteristic UUID
 *  and does not know the handle of the characteristic. The range is delimited by the start and end handles and is typically
 *  the handle range for the service in which the characteristic belongs.
 *
 * Parameters :
 * INPUTS
 *     u_int16 max_result_len   :- This is the maximum length of data which can be returned.
 *  u_int16 start_handle     :- The start of the range over which this read is to be performed.
 *  u_int16 end_handle       :- The end of the range over which this read is to be performed.
 *  u_int16 attrib_UUID      :- Attribute UUID of the characteristic to be read.
 *
 * OUTPUTS
 *  u_int8* p_result       :- The result field. A pointer to a characteristic or characteristic descriptor value.
 *
 *
 *  u_int8* p_result_len   :- A pointer the total length of valid data in the result field ( pointed to by p_result ).
 *
 *****************************************************************************************************/
// Was/Is BUG here with read by type for 16 Byte UUIDs
#if 1
//u_int8 GATTserver_Read_Characteristic_Value_By_UUID(u_int16 max_result_len,u_int16 start_handle,u_int16 end_handle,u_int16 attrib_UUID,u_int8* p_result,u_int8* p_result_len,u_int8* p_attrib_len)
u_int8 GATTserver_Read_Characteristic_Value_By_UUID(u_int16 max_result_len,u_int16 start_handle,u_int16 end_handle,t_attrib_UUID* p_att_UUID,u_int8* p_result,u_int8* p_result_len,u_int8* p_attrib_len)
{
    u_int16 i=0;
    u_int8 j;
    u_int8 result_len = 0;
    //u_int8* p_payload;
    u_int8 status;
    *p_result_len = 0x00;
    GATTserver_Handle_in_Error = start_handle;
    //p_payload = p_result;
    status = GATTserver_Find_DB_Index(start_handle,end_handle,&i);
    if (status != NO_ERROR)
    {
        return status;
    }
    // i now is the index to the start handle in the Server DB
    while ((GATTserver_DB[i].attrib_handle <= end_handle) && ((result_len+6) < max_result_len) && (i<=GATTserver_DB_last_index))/* TP/GPA/SR/BV-01-C bug fix*/
    {
        t_attrib* p_current_attrib = &GATTserver_DB[i];
        GATTserver_Handle_in_Error = GATTserver_DB[i].attrib_handle;
        // if the attrib_UUID match
        if (GATTserver_UUID_Match(&p_current_attrib->attrib_UUID,p_current_attrib->attrib_len,p_att_UUID))
        {
            status = GATTserver_Check_Permissions(p_current_attrib, GATT_READ);
            if (status != NO_ERROR)
            {
                return status;
            }
            // Add the Attribute Handle to the Result
            LMutils_Set_Uint16(p_result, p_current_attrib->attrib_handle);//charles modify
            if( (p_att_UUID->UUID_val == GATT_ATT_TYPE_PRIMARY_SERVICE) || (p_att_UUID->UUID_val == GATT_ATT_TYPE_SECONDARY_SERVICE))/* TP/GPA/SR/BV-01-C bug fix*/
            {
                u_int8 length = p_current_attrib->attrib_value.service.service_UUID_len ;/* TP/GPA/SR/BV-01-C bug fix*/
                // p_current_attrib->attrib_value.service.service_UUID.UUID_val = service_UUID;
                p_result[2] = (p_current_attrib->attrib_value.service.service_UUID.UUID_val) ;/* TP/GPA/SR/BV-01-C bug fix*/
                p_result[3] = (p_current_attrib->attrib_value.service.service_UUID.UUID_val) >> 8 ;/* TP/GPA/SR/BV-01-C bug fix*/
                result_len = *p_result_len += length+2;/* include handle length  TP/GPA/SR/BV-01-C bug fix */
                *p_attrib_len = length+2;/* include handle length TP/GPA/SR/BV-01-C bug fix*/
                //p_payload+=length;/* TP/GPA/SR/BV-01-C bug fix */
                p_result+=*p_attrib_len;/* TP/GPA/SR/BV-01-C bug fix */
                //return NO_ERROR;
                //if(*p_result_len >= 20)/* until MTU size charles modify*/
                //{
                //   return NO_ERROR;
                //}
            }
            else
                // Now get the pointer to the Attrib value and check attrib length.
            {
                u_int8* p_val = p_current_attrib->attrib_value.value.p_value;
                u_int8 length = p_current_attrib->attrib_value.value.val_len;
                if (length > max_result_len)
                {
                    length = max_result_len;
                }
                for (j=0; j<length; j++)
                {
                    p_result[j+2] = p_val[j];
                }
                result_len = *p_result_len += length+2;/* TP/GPA/SR/BV-01-C bug fix */
                *p_attrib_len = length+2;
                p_result+=*p_attrib_len;/* TP/GPA/SR/BV-01-C bug fix */
            }
        }
        i++;
    }
    if (*p_result_len == 0x00)
    {
        return GATT_ERROR_ATTRIBUTE_NOT_FOUND;
    }
    return NO_ERROR;
}
#endif
/*****************************************************************************************************
 * GATTserver_Write_Command
 * [ Note can be optimised to include the  GATT_Server_Charactaristic_Write_Local_Value also ]
 *
 *  This function is used to write a characteristic value or a characteristic descriptor value to the local Server DB.
 *  If the attrib_handle is the handle of a characteristic handle then the 'local notify' field is checked and if set
 *  then a Notification is sent locally to indicate the handle has been written to.
 *
 *  If the UUID for the attrib_handle is a RECONNECTION_ADDRESS then the reconnection_address_valid flag is set. This
 *  flag is used by the GAP.
 *
 * Parameters :
 * INPUTS
 *
 *     u_int16 attrib_handle      :- This is the handle for the characteristic or characteristic descriptor to be written
 *  u_int8* p_attrib_value     :- A pointer to the data to be written,
 *  u_int16 length             :- The number of octets of data to be written.
 *
 *
 *****************************************************************************************************/
u_int8 GATTserver_Write_Command(u_int16 attrib_handle, u_int8* p_attrib_value,u_int8 length)
{
    // First find the handle
    u_int8 i=0;
    t_GATT_error status = GATT_NO_ERROR;
    while ((GATTserver_DB[i].attrib_handle != attrib_handle) && (i<=GATTserver_DB_last_index))
    {
        i++;
    }
    if ((GATTserver_DB[i].attrib_handle != attrib_handle) ||
            ((GATTserver_DB[i].attrib_UUID.UUID_val >= 0x2800) && (GATTserver_DB[i].attrib_UUID.UUID_val <= 0x2803)))
    {
        return (t_error) GATT_ERROR_INVALID_HANDLE;
    }
    else
    {
        t_attrib* p_current_attrib = &GATTserver_DB[i];
        status = GATTserver_Check_Permissions(p_current_attrib, GATT_WRITE);
        if (status != GATT_NO_ERROR)
        {
            return status;
        }
        // Now write the Value...
        {
            //    u_int8 value_len  = p_current_attrib->attrib_value.value.val_len;
            u_int8 max_len = p_current_attrib->attrib_value.value.max_len;
            u_int8* p_value = p_current_attrib->attrib_value.value.p_value;
            u_int8 descriptor = 0x00;
            u_int16 UUID_val = p_current_attrib->attrib_UUID.UUID_val;
            if ((UUID_val >= 0x2900) && (UUID_val<= 0x2905))/* Characteristic Descriptor */
            {
                descriptor = 0x01;
            }
#if (PRH_BS_CFG_SYS_LE_GAP_RECONNECTION_ADDRESS_SUPPORTED==1)
            else if(UUID_val == RECONNECTION_ADDRESS)
            {
                if(GATTprivacy_Flags == 0)/* TP/CONN/UCON/BV-05-C GAP layer */
                {
                    status = GATT_ERROR_WRITE_NOT_PERMITTED;
                    return status;
                }
                reconnection_addr_valid = 0x01;
            }
#endif
#if ((PRH_BS_CFG_SYS_LE_GAP_PRIVACY_SUPPORTED==1) && (PRH_BS_CFG_SYS_LE_GAP_RECONNECTION_ADDRESS_SUPPORTED==1))
            else if (UUID_val == PERIPHERAL_PRIVACY_FLAGS)
            {
                if (*p_attrib_value == 0x01)
                {
                    // Enable Write of the Reconnection Address
                    GATTserver_DB[GATTserver_DB_Reconnection_Address_Index].permissions |= GATT_PERMISSION_WRITE;
                }
                else
                {
                    // Disable Write of the Reconnection Address
                    GATTserver_DB[GATTserver_DB_Reconnection_Address_Index].permissions &= (~GATT_PERMISSION_WRITE);
                }
            }
#endif
            //    else if ((GATTserver_DB[i].attrib_handle == CSC_SC_CONTROL_POINT_HANDLE))
            if (max_len < length)
            {
                return GATT_ERROR_INVALID_ATTRIBUTE_VALUE_LENGTH;
            }
            //if (length <= value_len)
            {
                u_int8 j;
                for (j=0; j<length; j++)
                {
                    p_value[j] = p_attrib_value[j];
                }
                p_current_attrib->attrib_value.value.val_len = length;
                if ((!descriptor) & (p_current_attrib->attrib_value.value.local_notification))//for ATT_WRITE command
                {
                    user_define_data_revice(p_value,length,i);
                    return 0;
                }
            }
        }
    }
    return 0;
}
/*****************************************************************************************************
 * GATTserver_Characteristic_Read_Local_Value
 *
 *  This function is used to read a characteristic value or a characteristic descriptor value from the local Server DB.
 *  This is invoked by the Local Host ( not the Client ).
 *
 * Parameters :
 * INPUTS
 *
 *     u_int16 char_val_handle      :- This is the handle for the characteristic or characteristic descriptor to be written
 *  u_int8** p_value             :- A pointer to pointer which will be set to the data being read,
 *  u_int8*  p_len               :- A pointer to the length of data which is read.
 *
 *
 *****************************************************************************************************/
t_GATT_error GATTserver_Characteristic_Read_Local_Value(u_int16 char_val_handle,u_int8* p_len,/*const*/ u_int8** p_value)
{
    u_int8 i=0;
    // Find the handle
    while ((GATTserver_DB[i].attrib_handle != char_val_handle) && (i<=GATTserver_DB_last_index))
    {
        i++;
    }
    if (GATTserver_DB[i].attrib_handle != char_val_handle)
    {
        return GATT_ERROR_ATTRIBUTE_NOT_FOUND;
    }
    else if ((GATTserver_DB[i].attrib_UUID.UUID_val >= 0x2800) && (GATTserver_DB[i].attrib_UUID.UUID_val <= 0x2803))
    {
        return GATT_ERROR_INVALID_HANDLE;
    }
    else
    {
        t_attrib* p_current_attrib = &GATTserver_DB[i];
        *p_value = p_current_attrib->attrib_value.value.p_value;
        *p_len = p_current_attrib->attrib_value.value.val_len;
    }
    return GATT_NO_ERROR;
}
/*****************************************************************************************************
 * GATTserver_Characteristic_Write_Local_Value
 *
 *  This function is used to write a characteristic value or a characteristic descriptor value to the local Server DB.
 *  This is invoked by the Local Host ( not the Client ).
 *
 *  If the char_val_handle is that of a Reconnection_address_descriptor the 'reconnection_addr_valid' flag is set.
 *
 *  If the handle is the handle of a characteristic value, then we search for a Client Configuration Characteristic (CCC) Descriptor
 *  included in the Characteristic Definition. If one is found then we check the value of the CCC and determine if a ATT_NOTIFY
 *  or ATT_INDICATION should be sent to the peer.
 *
 * Parameters :
 * INPUTS
 *
 *     u_int16 char_val_handle      :- This is the handle for the characteristic or characteristic descriptor to be written
 *  u_int8* p_attrib_value       :- A pointer to the data which is to be written.
 *  u_int8  length               :- length of data which is to be written.
 *
 *
 *****************************************************************************************************/
t_GATT_error GATTserver_Characteristic_Write_Local_Value(u_int16 char_val_handle,u_int8 length, u_int8* p_attrib_value)
{
    u_int8 l2cap_entry,lmp_entry;
    u_int8 i=0;
    u_int8 j=0;
    u_int16 char_UUID;
    l2cap_entry=BTq_Get_Queue_Number_Of_Entries(L2CAP_OUT_Q, 0);
    //  DEBUG_MSG(0XA8);
    //  DEBUG_MSG(l2cap_entry);
    lmp_entry=BTq_Get_Queue_Number_Of_Entries(LMP_OUT_Q, 0);
    //  DEBUG_MSG(lmp_entry);
    if(length<=20)
    {
        if((PRH_BS_CFG_SYS_NUM_OUT_ACL_PACKETS-l2cap_entry-lmp_entry)<1)
        {
            return GATT_ERROR_PREPARE_QUEUE_FULL;
        }
    }
    else
    {
        if((PRH_BS_CFG_SYS_NUM_OUT_ACL_PACKETS-l2cap_entry-lmp_entry)<((length-20)/24+2))
        {
            return GATT_ERROR_PREPARE_QUEUE_FULL;
        }
    }
    // Find the start handle
    while ((GATTserver_DB[i].attrib_handle != char_val_handle) && (i<=GATTserver_DB_last_index))
    {
        i++;
    }
    char_UUID = GATTserver_DB[i].attrib_UUID.UUID_val;
    if (GATTserver_DB[i].attrib_handle != char_val_handle)
    {
        return GATT_ERROR_ATTRIBUTE_NOT_FOUND;
    }
    else if ((char_UUID >= 0x2800) && (char_UUID <= 0x2803))
    {
        return GATT_ERROR_INVALID_HANDLE;
    }
    else
    {
        t_attrib* p_current_attrib = &GATTserver_DB[i];
        // Now write the Value...
        {
            //u_int8 value_len = p_current_attrib->attrib_value.value.val_len;
            u_int8 value_len = p_current_attrib->attrib_value.value.max_len;
            u_int8* p_value = p_current_attrib->attrib_value.value.p_value;
            // Now get the pointer to the Attrib value and check attrib length.
#if (PRH_BS_CFG_SYS_LE_GAP_RECONNECTION_ADDRESS_SUPPORTED==1)
            if(char_UUID == RECONNECTION_ADDRESS)
            {
                reconnection_addr_valid = 0x01;
            }
#endif
#if (PRH_BS_CFG_SYS_LE_GAP_PRIVACY_SUPPORTED==1)
            else if (char_UUID == PERIPHERAL_PRIVACY_FLAGS)
            {
                if (*p_attrib_value == 0x01)
                {
                    // Enable Write of the Reconnection Address
                    GATTserver_DB[GATTserver_DB_Reconnection_Address_Index].permissions |= GATT_PERMISSION_WRITE;
                }
                else
                {
                    // Disable Write of the Reconnection Address
                    GATTserver_DB[GATTserver_DB_Reconnection_Address_Index].permissions &= (~GATT_PERMISSION_WRITE);
                }
            }
#endif
            {
                if (length > value_len)
                {
                    length = value_len;
                }
                for (j=0; j<length; j++)
                {
                    p_value[j] = p_attrib_value[j];
                }
                for (j=length; j<value_len; j++)
                {
                    p_value[j]=0x00;
                }
            }
        }
        // Firstly Find the Client Characteristic Configuration (CCC) - if one exists
        // As Variable - i already is the index to the Characterisic value we scan the remainder of the
        // Characteristic descriptors until we find the CCC. Note the termination condictions of the search
        // are the end of the char descriptor declarations ( i.e UUID = 28XX or last_DB_index)
        i++; // To move one handle over the Characteristic Value.
        while ((GATTserver_DB[i].attrib_UUID.UUID_val != CLIENT_CHARACTERISTIC_CONFIGURATION) && (i<=GATTserver_DB_last_index) &&
                ((GATTserver_DB[i].attrib_UUID.UUID_val & 0xFF00) != 0x2800))//0x2800 Primary Service
        {
            i++;
        }
        if ((i<=GATTserver_DB_last_index) && (GATTserver_DB[i].attrib_UUID.UUID_val == CLIENT_CHARACTERISTIC_CONFIGURATION))
        {
            extern t_LE_Config LE_config;
            // We have found our CCC
            if (LE_config.num_le_links /* Connection Active */)
            {
                u_int8* p_config_value = GATTserver_DB[i].attrib_value.value.p_value;
                u_int16 config_value = ((u_int16)p_config_value[0] + ((u_int16) p_config_value[1] << 8));
                t_Att_pdu_params  pdu_params;
                t_Att_pdu_params* p_pdu_params = &pdu_params;
                if ((config_value == 0x01 /* Notify */) ||
                        (config_value == 0x02 /* Indicate - wait for Ack */))//master use Att write Client charcteristic configuration to set notify or indicate
                {
                    u_int8 opcode;
                    p_pdu_params->attribute.handle = char_val_handle;
                    p_pdu_params->attribute.p_value = p_attrib_value;
                    p_pdu_params->attribute.value_len = length;
                    if (config_value == 0x01 /* Notify */)
                    {
                        opcode = ATT_HANDLE_VALUE_NOTIFICATION;
                    }
                    else
                    {
                        opcode = ATT_HANDLE_VALUE_INDICATION;
                    }
                    // This is the only case where the PDU encoding is performed within
                    // the GATT server.
                    LEatt_Encode_PDU(16 /*connection_handle*/,opcode,p_pdu_params);
                    return GATT_NO_ERROR;
                    //if (config_value == 0x02 /* Indication */)
                    //{
                    //    return GATT_INDICATION_PENDING;
                    //}
                }
            }
            else /* No Connection Active */
            {
                /* Here I store the Handle in an array of pending indications.
                 * When the link is re-established the Application should call "service_pending_indications"
                 * Which will cycle through any pending indications or notifications.
                 */
                if (GATTserver_pending_Indications_Index < GATT_SERVER_MAX_PENDING_INDICATIONS)
                {
                    GATTserver_Pending_Indications[GATTserver_pending_Indications_Index++] = char_val_handle;
                }
            }
        }
    }
    return GATT_ERROR_WRITE_NOT_PERMITTED;
}
/*****************************************************************************************************
 * _GATTserver_Service_Pending_Indications
 *
 * This function is used to service any pending indications when a link is re-established.
 *
 *****************************************************************************************************/
t_GATT_error _GATTserver_Service_Pending_Indications(void)
{
    u_int16 i;
    for (i=0; i<GATTserver_pending_Indications_Index; i++)
    {
        u_int16 j=0;
        u_int16 char_UUID;
        // First get the first handle
        u_int16 char_val_handle = GATTserver_Pending_Indications[i];
        // Find the Data associated with the handle.
        while ((GATTserver_DB[j].attrib_handle != char_val_handle) && (j<=GATTserver_DB_last_index))
        {
            j++;
        }
        char_UUID = GATTserver_DB[j].attrib_UUID.UUID_val;
        if (GATTserver_DB[j].attrib_handle != char_val_handle)
        {
            return GATT_ERROR_ATTRIBUTE_NOT_FOUND;
        }
        else if ((char_UUID >= 0x2800) && (char_UUID <= 0x2803))
        {
            return GATT_ERROR_INVALID_HANDLE;
        }
        else
        {
            t_attrib* p_current_attrib = &GATTserver_DB[i];
            u_int8 value_len = p_current_attrib->attrib_value.value.max_len;
            u_int8* p_value = p_current_attrib->attrib_value.value.p_value;
            GATTserver_Characteristic_Write_Local_Value(char_val_handle, value_len, p_value);
        }
    }
    GATTserver_pending_Indications_Index = 0;
    return GATT_NO_ERROR;
}
/*****************************************************************************************************
 * _GATTserver_Find_End_Group_Handle
 *
 * This is a support function used to find the end handle of a PRIMARY or SECONDARY service definition
 *
 * INPUT
 * u_int16 current_index   :- The index into the database from which the search for the end handle should begin
 *****************************************************************************************************/
u_int16 _GATTserver_Find_End_Group_Handle(u_int16 current_index)
{
    u_int16 end_group_handle;
    current_index++;
    while((current_index <= GATTserver_DB_last_index) &&
            (GATTserver_DB[current_index].attrib_UUID.UUID_val != GATT_ATT_TYPE_PRIMARY_SERVICE) && (GATTserver_DB[current_index].attrib_UUID.UUID_val != GATT_ATT_TYPE_SECONDARY_SERVICE))
    {
        current_index++;
    }
    end_group_handle = GATTserver_DB[current_index-1].attrib_handle;
    return end_group_handle;
}
#if (PRH_BS_CFG_SYS_LE_GAP_PRIVACY_SUPPORTED==1)
/*****************************************************************************************************
 * GATTserver_Is_Privacy_Flag_Enabled
 *
 * Simple function used to return the setting of the PERIPHERAL_PRIVACY_FLAGS in the Sever DB
 *
 *****************************************************************************************************/
u_int8 GATTserver_Is_Privacy_Flag_Enabled()
{
#if 0
    if (GATTserver_DB_Peripheral_Privacy_Flag_Index == 0)
    {
        return 0;
    }
    else
    {
        return *(GATTserver_DB[GATTserver_DB_Peripheral_Privacy_Flag_Index].attrib_value.value.p_value);
    }
#else
    return GATTprivacy_Flags;
#endif
}
#endif
#if (PRH_BS_CFG_SYS_LE_GAP_RECONNECTION_ADDRESS_SUPPORTED==1)
/*****************************************************************************************************
 * GATTserver_Find_Reconnection_Address
 *
 * Simple function used to find the RECONNECTION_ADDRESS (if one is present) in the Server DB
 *
 *****************************************************************************************************/
u_int8* GATTserver_Find_Reconnection_Address()
{
    if (!reconnection_addr_valid)
    {
        return 0;
    }
    else
    {
        return GATTserver_DB[GATTserver_DB_Reconnection_Address_Index].attrib_value.value.p_value;
    }
}
#endif
#if (PRH_BS_CFG_SYS_LE_SERVER_SUPPORTS_PREPARE_WRITE==1)
/*****************************************************************************************************
 * GATTserver_Find_Reconnection_Address
 *
 * Simple function used to determine if a specific handle in the Server DB can be written.
 * Only required to support the ATT_PREPARED_WRITE capability
 *
 *****************************************************************************************************/
u_int8 GATTserver_Can_I_Write(u_int16 handle)
{
    u_int16 i;
    u_int8 status;
    t_attrib* p_current_attrib;
    // First Find the index for the handle
    status = GATTserver_Find_DB_Index(handle,0xFFFF,&i);
    if (status != NO_ERROR)
    {
        return status;
    }
    p_current_attrib = &GATTserver_DB[i];
    return GATTserver_Check_Permissions(p_current_attrib,GATT_WRITE);
}
#endif
#if (PRH_BS_CFG_SYS_LE_SERVER_SUPPORTS_LOCAL_MODIFICATION_OF_PERMISSIONS==1)
/*****************************************************************************************************
 * GATTserver_Write_Permissions
 *
 * This is used modify the permissions on an attribute handle. This is normally only
 * required for conformance tests (to allow permissions to be changed without re-building SW)
 *****************************************************************************************************/
u_int8 GATTserver_Write_Permissions(u_int16 handle,u_int8 permissions)
{
    u_int16 i=0;
    u_int8 status;
    status = GATTserver_Find_DB_Index(handle,0xFFFF,&i);
    if (status == NO_ERROR)
    {
        GATTserver_DB[i].permissions = permissions;
    }
    return status;
}
#endif
/*****************************************************************************************************
 * GATTserver_Check_Permissions
 *
 * Simple function used to check the permissions on a given attribute. This function is compliant with
 * the permissions as defined in Core Specification Ammendment 3  (CSA-3)
 *
 * INPUTS
 * t_attrib*  p_current_attrib  :- pointer to the attribute whose permissions are to be checked.
 * u_int8     action            :- The action the permissions are to be checked against.
 *                                  ( GATT_READ, GATT_WRITE )
 *
 *****************************************************************************************************/
t_GATT_error GATTserver_Check_Permissions(t_attrib* p_current_attrib,u_int8 action)
{
    if ((action == GATT_READ) && (!(p_current_attrib->permissions & GATT_PERMISSION_READ)))
    {
        return GATT_ERROR_READ_NOT_PERMITTED;
    }
    if ((action == GATT_WRITE) && (!(p_current_attrib->permissions & GATT_PERMISSION_WRITE)))
    {
        return GATT_ERROR_WRITE_NOT_PERMITTED;
    }
    // Check if authentication required
    if (p_current_attrib->permissions & GATT_PERMISSION_AUTHENTICATED)
    {
        /* if such a request is issued when the physical link is unauthenticated
         * or unencrypted, the server shall send an Error Response with the status code
         * set to Insufficient Authentication.
         */
#if (PRH_BS_CFG_SYS_LE_SMP_INCLUDED==1)
        if(!LEsmp_Check_Is_Link_Authenticated(GATT_Get_Active_Handle())) // ATT_config.connection_handle))
        {
            return GATT_ERROR_INSUFFICIENT_AUTHENTICATION;
        }
#endif
    }
    if (p_current_attrib->permissions & GATT_PERMISSION_AUTHORISED)
    {
        if(!GATTserver_Check_Is_Service_Authorised())
        {
            return GATT_ERROR_INSUFFICIENT_AUTHORISATION;
        }
    }
    if (p_current_attrib->permissions & 0xF0 /* Check if Encryption is needed - Top nibble of permissions used for Encry Key */)
    {
        t_GATT_error status = GATTserver_Check_Encryption_Key_Size(p_current_attrib->permissions);
        return status;
    }
    return GATT_NO_ERROR;
}
u_int8 GATTserver_UUID_Match(t_UUID* attrib_UUID,u_int8 attrib_len,t_attrib_UUID* p_att_UUID)
{
    if (attrib_len != p_att_UUID->len)
    {
        return 0;
    }
    else if (attrib_len == 0x02)
    {
        if (attrib_UUID->UUID_val != p_att_UUID->UUID_val)
        {
            return 0;
        }
    }
    else if (attrib_len == 0x10)
    {
        u_int8 i;
        for(i=0; i<16; i++)
        {
            if (attrib_UUID->p_UUID[i] != p_att_UUID->p_UUID[i])
            {
                return 0;
            }
        }
    }
    return 1;
}
#if (PRH_BS_CFG_SYS_LE_SERVER_SUPPORTS_PREPARE_WRITE==1)
/*****************************************************************************************************
 * GATTserver_Get_Value_Length
 *
 * Returns the maximum length of an attribute value.
 *
 * ONLY required if PREPARED_WRITE is supported
 *****************************************************************************************************/
u_int8 GATTserver_Get_Value_Length(u_int16 handle)
{
    u_int16 i;
    // First Find the index for the handle
    GATTserver_Find_DB_Index(handle,0xFFFF,&i);
    return GATTserver_DB[i].attrib_value.value.max_len;
}
#endif
/*****************************************************************************************************
 * GATTserver_Get_Reconnection_Address_Handle
 *
 * Simple function which returns the handle of the Reconnection Address, if available
 *****************************************************************************************************/
u_int16 GATTserver_Get_Reconnection_Address_Handle(void)
{
    return GATT_reconnection_address_handle;
}
/*****************************************************************************************************
 * _GATTserver_Check_Space_Available
 *
 * Simple function which checks is space is available for a new attribute.
 *****************************************************************************************************/
u_int8 _GATTserver_Check_Space_Available(u_int16 GATTserver_DB_next_index)
{
    return ((GATTserver_DB_next_index+1) <  MAX_GATT_SERVER_NUM_ENTRIES);
}
/***************************************
 * TO DO - TO BE COMPLETED
 ***************************************/
u_int8 GATTserver_Check_Is_Service_Authorised(void)
{
    return 0;
}
/*******************************************************************************
 * Function
 * GATTserver_Check_Encryption_Key_Size
 *
 * Description
 * Checks if the current key size is sufficient to access an attribute in the
 * GATT server database. The required key size is stored in the upper nibble of the
 * permissions.
 ********************************************************************************/
t_GATT_error GATTserver_Check_Encryption_Key_Size(u_int8 permissions)
{
#if (PRH_BS_CFG_SYS_LE_SMP_INCLUDED==1)
    u_int8 min_key_size = (permissions/16)+1;
    return (t_GATT_error) LEsmp_Check_Key_Size(GATT_Get_Active_Handle(),min_key_size);
#else
    return GATT_ERROR_INSUFFICIENT_ENCRYPTION_KEY_SIZE;
#endif
}
#endif
#endif
