/*************************************************
Copyright (C), 1988-1999, Tech. Co., Ltd.
File name: uart_protocol.h
Author:
Version:
Date:
Description:
Others:
History:
<author> <time> <version > <desc>
Simon 17/03/11 1.0 build this moudle
*************************************************/
#ifndef _DMP_MODULE_H_
#define _DMP_MODULE_H_
#include <stdint.h>
#include <string.h>
//cmd type define
#define DMP_TYPE_CMD                0x01
#define DMP_TYPE_NOTIFY             0x04
//header length define
#define DMP_HEADER_LENGTH           (3)
//package format memory offset
#define DMP_CMD_TYPE_OFFSET         0
#define DMP_CMD_ID_OFFSET           1
#define DMP_CMD_LEN_OFFSET          2
#define DMP_CMD_DATA_OFFSET         3
//length type,adapt to protocol
typedef unsigned char dmp_len_t;
//cmd ID define
#define CMD_SET_BT_NAME             0x11
#define CMD_SET_BLE_NAME            0x12
#define CMD_SET_PAIR_MODE           0x13
#define CMD_INPUT_PASSKEY           0x14
#define CMD_SET_CLASSIC_BT_PINCODE  0x15
#define CMD_ADV_ONOFF               0x16
#define CMD_SET_BLE_PINCODE         0x17
#define CMD_SET_GPIO                0x18
#define CMD_BT_REQUEST_STATUS       0x19
#define CMD_BLE_REQUEST_STATUS      0x1a
#define CMD_SEND_SPP_DATA           0x1b
#define CMD_SEND_BLE_DATA           0x1c
#define CMD_BT_DISCONN              0x1d
#define CMD_BLE_DISCONN             0x1e
#define CMD_DEEP_SLEEP              0x1f
#define CMD_REQUEST_VERSION         0x20
#define CMD_SET_UUID_SERVICE        0X21
#define CMD_SET_UUID_NOTIFY         0X22
#define CMD_SET_UUID_WRITE          0X23
#define CMD_RESET_BT                0X24
#define CMD_INQURIY_DEVICE_STATUS   0X25
#define CMD_PASSKEY_CONFIRM         0x26
#define CMD_REQUEST_BT_NAME         0x27
#define CMD_REQUEST_BLE_NAME        0x28
#define CMD_REQUEST_BT_MAC_ADDR     0x29
#define CMD_REQUEST_BLE_MAC_ADDR    0x2A
#define CMD_REQUEST_BT_PAIR_MODE    0x2B
#define CMD_REQUEST_BLE_PAIR_MODE   0x2C
#define CMD_REQUEST_BT_PIN_CODE     0x2D
#define CMD_REQUEST_BLE_PIN_CODE    0x2E
#define CMD_REQUEST_ENTER_LOWPWR    0x2F
#define CMD_REQUEST_GPIO_STATUS     0x30
#define CMD_REQUEST_VOLTAGE         0x31
#define CMD_SET_BAUDRATE            0x40
#define CMD_FLOW_CONTROL_ON_OFF     0x41
#define CMD_SET_COD                 0x42
#define CMD_SET_ADV_DATA            0x43
#define CMD_SET_ADV_RESPONSE_DATA   0x44
#define CMD_SET_VOLTAGE_CHECK_ONOFF 0x45
#define CMD_SET_BT_ADDR             0x46
#define CMD_ENTER_UART_UPDATA       0x75
#define CMD_SEND_FLASH_ERASE        0x76
#define CMD_SEND_UPDATAT_DATA       0x77
#define CMD_SEND_UPDATA_END         0x78
#define CMD_SEND_UPDATA_OK          0x79
#define CMD_MASTER_UART_CLOSED      0x50
#define CMD_MASTER_UART_OPENED      0x51
#define NOTIFY_DEVICE_READY         0x81
#define NOTIFY_OPERATION_RESULT     0x82
#define NOTIFY_STATUS               0x83
#define NOTIFY_BT_CONN_STATUS       0x84
#define NOTIFY_BLE_CONN_STATUS      0x85
#define NOTIFY_BT_DISCONNECTED      0x86
#define NOTIFY_BLE_DISCONNECTED     0x87
#define NOTIFY_SPP_RECEIVED_DATA    0x88
#define NOTIFY_BLE_RECEIVED_DATA    0x89
#define NOTIFY_RELEASE_VERSION      0x8a
#define NOTIFY_INVALID_PACKAGE      0x8b
#define NOTIFY_PASSKEY_REQUEST      0x8C
#define NOTIFY_CONFIRM_REQUEST      0x8D
#define NOTIFY_SPP_SEND_RESULT      0x8E
#define NOTIFY_BLE_SEND_RESULT      0x8F
#define NOTIFY_BT_NAME              0x90
#define NOTIFY_BLE_NAME             0x91
#define NOTIFY_BT_MAC_ADDR          0x92
#define NOTIFY_BLE_MAC_ADDR         0x93
#define NOTIFY_BT_PAIR_MODE         0x94
#define NOTIFY_BLE_PAIR_MODE        0x95
#define NOTIFY_BT_PIN_CODE          0x96
#define NOTIFY_BLE_PIN_CODE         0x97
#define NOTIFY_ENTER_LOWPWR_RESULT  0x98
#define NOTIFY_GPIO_STATUS          0x99
#define NOTIFY_VOLTAGE              0x9A
#define NOTIFY_IN_UPDATA_MODE       0xA5
#define NOTIFY_FLASH_ERASE_STATUS   0xA6
#define NOTIFY_UPDATA_DATA_STATUS   0XA7
#define NOTIFY_UPDATA_END_STATUS    0XA8
#define NOTIFY_ERROR_CODE           0XAE
//pair mode define
#define DMP_SIMPLE_PAIR         0x01
#define DMP_PIN_CODE_PAIR       0x02
//bt data max length.(CMD_SEND_SPP_DATA)
#define DMP_SPP_MAX_DATALEN     (100)
#define DMP_BLE_MAX_DATALEN     (128)
//emergency event for upload.(NOTIFY_STATUS)
#define EME_SPP_CONNECTED               0x01
#define EME_BLE_CONNECTED               0x02
#define EME_SPP_DISCONNECTED            0x03
#define EME_BLE_DISCONNECTED            0x04
#define EME_UART_BLOCK                  0x05
#define EME_UART_UNBLOCK                0x06
#define EME_PAIR_REQUEST                0x07
#define EME_PAIR_SUCCEED                0x08
#define EME_PAIR_FAIL                   0x09
//operation result define
#define RESULT_SUCCESS      (1)
#define RESULT_FAILD        (0)
//error code define
#define INVALID_DATA_LENGTH     (0x01)
#define UNRECOGNIZED_COMMAND    (0x02)
#define CRC_FAILDED             (0x03)
#define INCRRECT_DATA           (0x04)
#define BT_NO_CONNECT           (0x05)
#define REQUEST_FAILD           (0x06)
#define QUEUE_FULL              (0x07)
#define NO_PERMISION            (0x08)
//others
#define MAX(x,y)            ((x>y)?x:y)
#define ARRAY_LEN(array)    (sizeof(array)/sizeof(array[0]))
#define MAX_BUF_ROW 3
#define MAX_BUF_CNT 128
extern RW_RAM u_int8 ble_data_buff[MAX_BUF_ROW][MAX_BUF_CNT],ble_data_len[MAX_BUF_ROW];
extern RW_RAM u_int8 ble_data_write,ble_data_read,ble_data_cnt;
//packge struct define
typedef struct
{
    u_int8 cmd_type;
    u_int8 cmd_id;
    u_int8 data_len;
    u_int8 *content;
} DMP_package_t;
extern u_int8 bt_default_open;
void notify_status(u_int8 emEvent);
void notify_spp_received(u_int8 *data, dmp_len_t dataLen);
void notify_ble_received(u_int8 *data, dmp_len_t dataLen);
void dmp_cmd_dispath(u_int8 *p_data, dmp_len_t len);
void dmp_module_init(void);
void dmp_self_test(void);
void send_notify_passkey_request(void);
void send_notify_confirm_request(u_int8 *passkey,u_int8 dataLen);
void notify_ble_send_result(u_int8 result, u_int8 err_code);
void timer1_callback(void) ;
void send_notify_device_ready(u_int8 status);
void gpio_wakeup_set(void);
void notify_data_to_mcu(void);
void check_key_active(u_int16 threashold);
//void gpio_wakeup_enable(void);
void uart_flow_ctrl(void);
#endif
