#include "bk3000_reg.h"
#include "sys_hal_types.h"
#include "DeviceBtj_Header.h"
#include "bk3000_mfc.h"
#include "flash.h"

static void driver_mfc_write_dword(u_int8 space_control, u_int16 flash_address, u_int32 flash_data)
{
    BK3000_MFC_WE_P1=0XA5;
    BK3000_MFC_WE_P2=0XC3;
    BK3000_MFC_DATA = flash_data;
	BK3000_MFC_ADDR = (flash_address/4);
	BK3000_MFC_KEYWORD = 0x58a9;
	BK3000_MFC_KEYWORD = 0xa958;
	BK3000_MFC_CTL = (1<<2);
	BK3000_MFC_CTL |= (space_control<<5);
	BK3000_MFC_CTL |= (1<<0);
	while(BK3000_MFC_CTL&BIT_0);
    //BK3000_MFC_WE_P2=0X00;
    //BK3000_MFC_WE_P1=0X00;
}

static u_int32 driver_mfc_read_dword(u_int8 space_control, u_int32 flash_address)
{
    BK3000_MFC_ADDR = (flash_address/4);
	BK3000_MFC_KEYWORD = 0x58a9;
	BK3000_MFC_KEYWORD = 0xa958;
	BK3000_MFC_CTL = (0<<2);
	BK3000_MFC_CTL |= (space_control<<5);
	BK3000_MFC_CTL |= (1<<0);
	while(BK3000_MFC_CTL&BIT_0);
	return BK3000_MFC_DATA;
}

void driver_mfc_erase_sector(u_int8 space_control, u_int16 flash_address)
{
    BK3000_MFC_WE_P1=0XA5;
    BK3000_MFC_WE_P2=0XC3;
  
    BK3000_MFC_ADDR = flash_address;
	BK3000_MFC_KEYWORD = 0x58a9;
	BK3000_MFC_KEYWORD = 0xa958;
	BK3000_MFC_CTL = (2<<2);
	BK3000_MFC_CTL |= (space_control<<5);
	BK3000_MFC_CTL |= (1<<0);
	while(BK3000_MFC_CTL&BIT_0);
    //BK3000_MFC_WE_P2=0X00;
    //BK3000_MFC_WE_P1=0X00;
}

void driver_mfc_write_byte(u_int8 space_control, u_int16 flash_address, u_int8 flash_data)
{
    u_int8 i;
    u_int32 temp_data;

    u_int8 flash_context[0xff];

    driver_mfc_read_buf(space_control, 0x0, flash_context, 0xff);
    flash_context[flash_address] = flash_data;
    driver_mfc_erase_sector(space_control, 0x0);
    for(i=0; i<64; i++)
    {
        temp_data = flash_context[4*i+3];
        temp_data = (temp_data<<8)|flash_context[4*i+2];
        temp_data = (temp_data<<8)|flash_context[4*i+1];
        temp_data = (temp_data<<8)|flash_context[4*i+0];
        driver_mfc_write_dword(space_control, i*4, temp_data);
    }
}

u_int8 driver_mfc_read_byte(u_int8 space_control, u_int32 flash_address)
{
    u_int32 temp_data = driver_mfc_read_dword(space_control, flash_address);
    return ((u_int8)(temp_data>>((flash_address%4)*8)));
}

void driver_mfc_write_buf(u_int8 space_control, u_int16 flash_address, u_int8* data_buf, u_int8 data_len)
{
    u_int8 i;
    u_int32 temp_data;

    u_int8 flash_context[0xff];

    driver_mfc_read_buf(space_control, 0x0, flash_context, 0xff);
    memcpy(&flash_context[flash_address], data_buf, data_len);
    driver_mfc_erase_sector(space_control, 0x0);
    for(i=0; i<64; i++)
    {
        if( (i==62)&& (space_control==NVR_SPACE)&&(data_len==LINK_KEY_SAVE_BUF_LEN))
            temp_data=(flash_address-128)/data_len;
        else     
            temp_data = flash_context[4*i+3];
        
        temp_data = (temp_data<<8)|flash_context[4*i+2];
        temp_data = (temp_data<<8)|flash_context[4*i+1];
        temp_data = (temp_data<<8)|flash_context[4*i+0];
        driver_mfc_write_dword(space_control, i*4, temp_data);
    }
}

void driver_mfc_read_buf(u_int8 space_control, u_int32 flash_address, u_int8* data_buf, u_int8 data_len)
{
    while(data_len)
    {
        *data_buf = driver_mfc_read_byte(space_control, flash_address);
        flash_address++;
        data_buf++;
        data_len--;
    }
}