
#include "include.h"
#include "DeviceBtj_Header.h"


/// Specific to EMBED BEKEN FLASH  (type 1)
#define FLASH_SECT_SIZE1         0x00000200  //  512 Byte
#define FLASH_SECT_SIZE2         0x00001000  //  4 KByte
#define FLASH_BOUNDARY256B       0x00000100  // 256 Byte



/// Flash environment structure
struct flash_env_tag
{
    u_int32    length[2];
   
    u_int8     space_type[2];
};


static struct flash_env_tag flash_env;



static void flash_unlock(void)
{
    // Unlock all sectors
    REG_AHB3_MFC_WP0 = 0xA5;
    REG_AHB3_MFC_WP1 = 0xC3;
}
 
static void flash_writeKey(void)
{
    // write control key
    REG_AHB3_MFC_KEYWORD = 0x58A9;
    REG_AHB3_MFC_KEYWORD = 0xA958;
}

static void flash_clearKey(void)
{
    // write control key
    REG_AHB3_MFC_KEYWORD = 0x0;
    REG_AHB3_MFC_KEYWORD = 0x0;
}
 
static void flash_start(void)
{
    REG_AHB3_MFC_CONTROL |= 0x01;
}

static u_int8 flash_status(void)
{
    return REG_AHB3_MFC_CONTROL & 0x01;
}

 void flash_init(void)
 {
     // Init flash environment    
     flash_env.length[0]    =  FLASH_MAIN_SIZE;
     flash_env.space_type[0]  = FLASH_SPACE_TYPE_MAIN; 
     
     flash_env.length[1]    =  FLASH_NVR_SIZE;
     flash_env.space_type[1]  = FLASH_SPACE_TYPE_NVR;
  
 }
 

 u_int32 flash_readword(u_int8 type,u_int32 address)
{
    u_int32 reg;
    u_int32 data;
    

    REG_AHB3_MFC_ADDR = address;

    flash_writeKey(); // write key
    flash_unlock(); //wipe off WP

    reg = REG_AHB3_MFC_CONTROL;
    reg &= ~((0x07 << 2) | (0x03 << 5)); //clear control mode and space
    reg  |= ( MFC_CONTROL_READ | (type << 5)); // set write mode and control space
    REG_AHB3_MFC_CONTROL = reg;

    flash_start();

    while(flash_status() == 1);

    data = REG_AHB3_MFC_DATA;
    flash_clearKey();
    return data;
}

 void flash_writeword(u_int8 type,u_int32 address, u_int32 data)
{
    u_int32 reg;
   
    REG_AHB3_MFC_ADDR = address;
    /* Write the data                                                                   */
    REG_AHB3_MFC_DATA = data;
    flash_writeKey(); // write key
    flash_unlock(); //wipe off WP
    reg = REG_AHB3_MFC_CONTROL;
    reg &= ~((0x07 << 2) | (0x03 << 5)); //clear control mode and space
    reg  |= ( MFC_CONTROL_WRITE | (type << 5)); // set write mode and control space
    REG_AHB3_MFC_CONTROL = reg;
    flash_start();
    while(flash_status()) ;
    flash_clearKey();
	
}



void flash_erase_sector(u_int8 type,u_int32 address)
{

    u_int32 reg;

    REG_AHB3_MFC_ADDR = address;

    flash_writeKey(); // write key
    flash_unlock(); //wipe off WP

    reg = REG_AHB3_MFC_CONTROL;
    reg &= ~((0x07 << 2) | (0x03 << 5)); //clear control mode and space
    reg  |= ( MFC_CONTROL_SECT_ERASE | (type << 5)); // set write mode and control space
    REG_AHB3_MFC_CONTROL = reg;

    flash_start();

    while(flash_status());
    flash_clearKey();
}




void flash_erase(u_int8 flash_type, u_int32 address, u_int32 size)
{
    u_int32 end_address;

    end_address = address + size;

    // Check parameters
    if ( (flash_type > FLASH_SPACE_TYPE_NVR)  )
    {		
        return ;
    }

    address = address & ~(FLASH_SECT_SIZE1 - 1);
  
    while(address < end_address)
    {
    
        flash_erase_sector(flash_type,address);
        
       /* Calculate next sector address (below 0x000100) */
        address += FLASH_SECT_SIZE1;
        
    }

    return ;
}

void flash_write(u_int8 flash_space, u_int32 address, u_int32 length, u_int8 *buffer)
{
    u_int32 data = 0xffffffff;
    u_int8  cnt;
   

   
    // Check parameters
    if ( (flash_space > FLASH_SPACE_TYPE_NVR) || (( length) > flash_env.length[flash_space]) )
    {
        return ;
    }

    while(length >= 4)
    {
        data = (buffer[0] | (buffer[1] << 8) | (buffer[2] << 16) | (buffer[3] << 24)); 
        
        flash_writeword(flash_space,address , data);

        address += 1;
        buffer += 4;
        length -= 4;
        //bprintf("Data = %x length = %x\r\n",data,length);
    }

    if(length != 0)
    { /* write last mutil byte */
        data = 0xffffffff;
				
        for(cnt = 0; cnt < length;cnt++)
        {
            data &= ~(0xff << (8 * cnt));
            data |= (buffer[cnt] << (8 * cnt )) ;
        }

        flash_writeword(flash_space,address, data);
        //	uart_printf("Data2 = 0x%08x length = %d\r\n",Data,length);
    }

    return ;
}

void flash_read(u_int8 flash_space, u_int32 address, u_int32 length, u_int8 *buffer)
{
    u_int32 data = 0xffffffff;

    u_int8 cnt;
    
    // Check parameters
    if (  length > flash_env.length[flash_space] )
    {        
        return ;
    }

    if ( flash_space > FLASH_SPACE_TYPE_NVR )
    {        
        return ;
    }


    while(length >= 4)
    {
			
        data = flash_readword(flash_space,address);
		//bprintf("read data0 = %x\r\n",data);		
        memcpy(buffer, &data, 4);
        address += 1;
        buffer += 4;
        length -= 4;
    }

    if(length != 0)
    {
				
        /* read last byte */
        data = flash_readword(flash_space,address);

        for(cnt = 0; cnt < length;cnt++)
        {
            *buffer++ = ( data >> (cnt  * 8) & 0xFF );
        }

    }

    return ;
}




#if 0
static uint16 crc16 (uint8 *pbuff, uint32 len)
{
    uint32 i,j;
    uint8 ds;
    uint16 crc = 0xffff;
    static uint16 poly[2]={0, 0xa001}; 
    for(j=len; j>0; j--)
    {
        ds = *pbuff++;
        for(i=0; i<8; i++)
        {
            crc = (crc >> 1) ^ poly[(crc ^ ds ) & 1];
            ds = ds >> 1;
        }
    }
    return crc;
}

void write_lmecc_pointq(uint8 *buff1, uint8 *buff2)
{
    uint8 temp_buff[60],i;
    uint16 temp_crc;

    memcpy(&temp_buff[0],buff1,28);
    memcpy(&temp_buff[28],buff2,28);
    
    flash_erase_sector(0x42000);
    temp_buff[56]=FLASH_WRITE_ECC_DATA0;
    temp_buff[57]=FLASH_WRITE_ECC_DATA1;
    temp_crc=crc16(temp_buff,58);
    temp_buff[58]=temp_crc&0xff;
    temp_buff[59]=temp_crc>>8;

    flash_write_data(temp_buff,0x42000,60);
    
    
}


uint8 read_lmecc_pointq_status(void)
{
    
    uint8 temp_buff[60],i;
    uint16 crc_data=0;
    
    flash_read_data(temp_buff,0x42000,60);
    

    crc_data=crc16(temp_buff,58);
    
    if((temp_buff[56]==FLASH_WRITE_ECC_DATA0) && (temp_buff[57]==FLASH_WRITE_ECC_DATA1) 
        && ((crc_data&0xff)==temp_buff[58])&&((crc_data>>8)==temp_buff[59]) )
    {
        return 1;
    }
    else
        return 0;
     
}

void read_lmecc_pointq( uint8 *buff1,uint8 *buff2 )
{
    uint8 temp_buff[58];
    
    flash_read_data(temp_buff,0x42000,58);
    
    memcpy(buff1,&temp_buff[0],28);
    memcpy(buff2,&temp_buff[28],28);
    
}
#endif




