;
; MODULE:         sys_boot.s
; PROJECT:        BlueStream
; MAINTAINER:     Ivan Griffin
; CREATION DATE:  28 September 2000
; DESCRIPTION:    common ARM system boot-code
;
; SOURCE CONTROL: $Id: sys_boot.s,v 1.11 2004/07/07 14:30:48 namarad Exp $
;
; REVISION HISTORY:
;    14.Sept.2000         IG      Based on sys_boot.s for AEB
;
; LICENSE:
;     This source code is copyright (c) 2000-2004 Ceva Inc.,
;     All rights reserved.
;

    PRESERVE8
    AREA SYS_Boot, CODE, READONLY

    EXPORT SYSboot_Startup
    IMPORT main
	  
    IMPORT SYSpost_Test[WEAK]
    IMPORT hc_warm_reset[WEAK]

    IMPORT SYSirq_IRQ_Handler
    IMPORT SYSirq_FIQ_Handler
 
    IMPORT SYSbuild_Info_Dummy[WEAK]
                                                  ; stripping vector table

;
; common ARM Definitions
;

MODE_USR    EQU    0x10
MODE_FIQ    EQU    0x11
MODE_IRQ    EQU    0x12
MODE_SVC    EQU    0x13
MODE_ABORT  EQU    0x14
MODE_UNDEF  EQU    0x15
MODE_SYS    EQU    0x1F

I_BIT       EQU    0x80
F_BIT       EQU    0x40


; common ARM code
;
;
; THIS IS THE ENTRY POINT FOR THE ROM BUILD!!!
; On power-up, the flash is located at 0x00000000
; Program Counter starts at 0x00000000, and we jump to 
; high flash at 0x04000000

    
    EXPORT SYS_Vector_Init_Block
	ENTRY

SYS_Vector_Init_Block
    LDR PC, _Reset_Addr
    LDR PC, _Undefined_Addr
    LDR PC, _SWI_Addr
    LDR PC, _Prefetch_Abort_Addr
    LDR PC, _Data_Abort_Addr
    NOP
    LDR PC, _IRQ_Addr ;restore for current hardware
    LDR PC, _FIQ_Addr ;restore for current hardware
    
   

_Reset_Addr            DCD SYSboot_Startup
_Undefined_Addr        DCD _Undefined_Handler
_SWI_Addr              DCD _SWI_Handler
_Prefetch_Abort_Addr   DCD _Prefetch_Abort_Handler
_Data_Abort_Addr       DCD _Abort_Handler
                       DCD 0                       ; Reserved Vector
_IRQ_Addr              DCD SYSirq_IRQ_Handler ; SYSirq_IRQ_Handler  
_FIQ_Addr              DCD SYSirq_FIQ_Handler


_Undefined_Handler
_SWI_Handler
_Prefetch_Abort_Handler
_Abort_Handler
    B _Abort_Handler

          
;
; FUNCTION:     SYSboot_Startup
; DESCRIPTION:  Cold-Boot Startup routine
;
SYSboot_Startup
	    MOV R0, #0
	    MOV R1, #0
	    MOV R2, #0
	    MOV R3, #0
	    MOV R4, #0
	    MOV R5, #0
	    MOV R6, #0
	    MOV R7, #0
	    MOV R8, #0
	    MOV R9, #0
	    MOV R10, #0
	    MOV R11, #0
	    MOV R12, #0



        BL      _SYSboot_Setup_Stacks_Disable_Intr

        BL      _SYSboot_ZI_Init

        BL      _SYSboot_Copy_CODE_To_SRAM


        LDR PC, =main                         ; and go!

    


_Dummy
        LDR PC, =SYS_Vector_Init_Block            ; dummy to prevent linker - not working for ADS linker
        LDR PC, =SYSbuild_Info_Dummy              ; dummy to prevent linker - not working for ADS linker
                                                  ; stripping vector table
_SYSboot_halt   B       _SYSboot_halt             ; should never reach here!!!


; **********************************************************************

;
; Need to include Target Specific ARM Code
;
       INCLUDE sys_boot_chimera.s                    

; **********************************************************************

;
; FUNCTION:     _SYSboot_Copy_CODE_To_SRAM
; DESCRIPTION:  copy main stack code from FLASH/ROM to SRAM
;
_SYSboot_Copy_CODE_To_SRAM

    IMPORT |Load$$RAM$$Base|[WEAK]         ; Load Addr of RAM (RW) 
    IMPORT |Image$$RAM$$Base|[WEAK]        ; Exec Addr of RAM (RW)
    IMPORT |Image$$RAM$$Length|[WEAK]      ; Length of RAM Exec (RW)

        LDR     R0, =|Load$$RAM$$Base|
        LDR     R1, =|Image$$RAM$$Base|
        MOV     R2, R1
        LDR     R4, =|Image$$RAM$$Length|
        ADD     R2, R2, R4
_copy                                       ; block copy function
        CMP r1, r2
        LDRLO   R3, [r0], #4
        STRLO   R3, [r1], #4
        BLO     _copy
        ;MOV     PC, LR
		BX lr

		mov r0,#1

 

;
; Generic ARM routines to setup the LSRAM and SRAM and jump into C code
;

; FUNCTION:     _SYSboot_ZI_Init
; DESCRIPTION:  Initialise Zero-Init Data Segment
;

_SYSboot_ZI_Init

    IMPORT |Image$$RAM$$ZI$$Base|    ; Exec Addr of RAM (ZI)
    IMPORT |Image$$RAM$$ZI$$Length|  ; Length of RAM Exec (ZI)
		
        LDR R2, =|Image$$RAM$$ZI$$Length|
        LDR R0, =|Image$$RAM$$ZI$$Base|
        MOV R1, R0
        ADD R1, R1, R2
        MOV R2, #0
_ZI_Loop
        CMP R0, R1
        STRLO R2, [R0], #4
        BLO _ZI_Loop
		;MOV PC, LR
		BX lr


        
        
        

    EXPORT __user_initial_stackheap


__user_initial_stackheap    
    LDR   r0,=bottom_of_heap
    ;MOV   pc,lr
	BX lr


__rt_div0
        B       __rt_div0      
          
        AREA    Myheap, DATA, NOINIT, ALIGN=2
bottom_of_heap     SPACE   256  ;



    END
