/******************************************************************************
 *
 * MODULE NAME:    sys_irq.c
 * PROJECT CODE:   BlueStream
 * DESCRIPTION:    Hardware Interrupt Interface - Chimera
 * MAINTAINER:     Ivan Griffin/Cyril Jean
 * DATE:           09 August 1999
 *
 * SOURCE CONTROL: $Id: sys_irq.c,v 1.102 2009/04/28 16:08:51 morrisc Exp $
 *
 * LICENSE:
 *     This source code is copyright (c) 2000-2004 Ceva Inc.
 *     All rights reserved.
 *
 * REVISION HISTORY:
 *    09 Aug 1999 -   IG       -  Initial Version
 *    Oct 2000    -   CJ       -  Port to Chimera
 *
 ******************************************************************************/
#include "sys_config.h"
#include "sys_types.h"
#include "sys_features.h"
#include "sys_config.h"
#include "sys_power.h"
#include "sys_irq.h"
#include "lc_types.h"
#include "lslc_slot.h"
#include "lslc_irq.h"
#include "hw_jalapeno.h"
#include "hw_register.h"
#include "hw_macro_defs.h"
#include "sys_mmi.h"
#include "tra_hcit.h"
#include "lmp_config.h"
#include "DeviceBtj_Header.h"
#include "app_dmp_module.h"
//#include "le_link_layer.h"
#include "driver_icu.h"

#ifndef __USE_INLINES__
#include "sys_irq_chimera_impl.h"
#endif


#define IRQ_ENTRY  __attribute__((section("irq_entry")))
#define FIQ_ENTRY  __attribute__((section("fiq_entry")))
extern t_LMconfig g_LM_config_info;


#define IRQ_VECTOR (unsigned *)   0x18
#define FIQ_VECTOR (unsigned *)   0x1c
#define MASK_24_BIT         0xff000000
#define BRANCH_OP_CODE      0xea000000

#define PIPE_OFFSET               0x08
#define WORD_OFFSET               0x02

/******************************************************************************
 *
 * Module variables
 *
 ******************************************************************************/
#if (PRH_BS_DEV_USE_DELAYED_SERVICE_ROUTINES == 1)
#define DSRS_TABLE_SIZE		10

static volatile u_int32 pending_dsr_counter;
static volatile u_int32 dsr_lock;
static volatile u_int32 dsr_table_head;
static volatile u_int32 dsr_table_tail;

static void (*pending_dsr_table[DSRS_TABLE_SIZE])(void);
#endif

//extern volatile u_int8 flag_system_active;
extern volatile u_int8 flag_key_down;
extern volatile u_int8 b_26M_colsed;

/******************************************************************************
 *
 * FUNCTION:  SYSirq_IRQ_Handler
 * PURPOSE:   Services slow interrupt requests to micro-controller
 *
 ******************************************************************************/
extern uint8 sniff_latency_count;
extern void sniff_gpio_wakeup(void);
void FIQ_Exception(void)//FIQ_Exception(void)
//__IRQ__ void  SYSirq_FIQ_Handler(void)
{
    unsigned int IntStat ;
   
    cpu_wakeup();

    IntStat = REG_AHB0_ICU_INT_STATUS_FLAG;

    if(IntStat & INT_STATUS_CEVA)
    {
	 switch_clk(MCU_CLK_32M);   
        LSLCirq_IRQ_Handler();   		  
    }


    REG_AHB0_ICU_INT_STATUS_FLAG= IntStat;
}

void IRQ_Exception(void)//FIQ_Exception(void)
//__IRQ__ void  SYSirq_IRQ_Handler(void)
{
    unsigned int IntStat;

    cpu_wakeup();
    

    IntStat = REG_AHB0_ICU_INT_STATUS_FLAG;

    if(IntStat & INT_STATUS_UART)          //Uart1 Int Assert
    {
	 switch_clk(MCU_CLK_32M);
        UART_Interrupt_Handler();
    }
    if(IntStat & INT_STATUS_GPIO)           //GPIO Int Assert
    {
        //bprintf("GPIO_int\r\n");
	 switch_clk(MCU_CLK_32M);
        sys_flag |= FLAG_GPIO_INTERRUPT;
        sniff_latency_count=0;	
	 sys_flag |= FLAG_KEY_ACTIVE;
        if(SYSpwr_Is_Low_Power_Mode_Active())
        {
            SYSpwr_Handle_Early_Wakeup();
	     if(sys_flag & FLAG_CONNECTED)
                sniff_gpio_wakeup();
        }
        gpio_wakeup_set();
    }

    if(IntStat & INT_STATUS_TIMER0)
    {
        Timer_ISR0();
    }
    if(IntStat & INT_STATUS_TIMER1)
    {
        Timer_ISR1();
    }
    if(IntStat & INT_STATUS_TIMER2)
    {
        Timer_ISR2();
    }

/*    if(IntStat & INT_STATUS_RTC)           //RTC Int Assert
    {

    }
    if(IntStat & INT_STATUS_PWM1)
    {

    }*/
    if(IntStat & INT_STATUS_ADC)            //ADC Int Assert
    {
        adc_isr();
    }

 /*   if(IntStat & INT_STATUS_I2C)           //I2c1 Int Assert
    {

    }

    if(IntStat & INT_STATUS_SPI)           //Spi1 Int Assert
    {

    }*/

    REG_AHB0_ICU_INT_STATUS_FLAG= IntStat;
}






/* stub for proper compilation */
void SYSirq_IRQ_Tabasco_ISR(void)
{
}



/******************************************************************************
 *
 * FUNCTION:  SYSirq_Disable_Interrupts_Save_Flags
 * PURPOSE:   Disables ARM IRQ and FIQ Interrupts, saves previous
 *            PSR
 *
 ******************************************************************************/
void SYSirq_Disable_Interrupts_Save_Flags(u_int32 *flags)
{
	   #pragma arm
#ifndef __GNUC__
    u_int32 current_flags,my_tmp_flags;
    __asm
    {
	    MRS current_flags, CPSR                 /* Get current CPSR */
        AND my_tmp_flags, current_flags, #0xc0  /* Clear all ex. IRQ and FIQ */
        STR my_tmp_flags, [flags]               /* "save" flags */
#if (PRH_BS_DEV_UART_FIQ_ALWAYS_ENABLED==1)
        ORR current_flags, current_flags, #0x80 /* Disable IRQ Only */
#else
        ORR current_flags, current_flags, #0xc0 /* Disable IRQ and FIQ */
#endif
        MSR CPSR_c, current_flags                 /* Write back */
    }
#else
    /* GNU C inline asm? */
#endif
}

void SYSirq_Disable_Interrupts_Only_IRQ_Save_Flags(u_int32 *flags)
{
	   #pragma arm
#ifndef __GNUC__
    u_int32 current_flags,my_tmp_flags;
    __asm
    {
	MRS current_flags, CPSR                 /* Get current CPSR */
        AND my_tmp_flags, current_flags, #0xc0  /* Clear all ex. IRQ and FIQ */
        STR my_tmp_flags, [flags]               /* "save" flags */

        ORR current_flags, current_flags, #0x80 /* Disable IRQ Only */

        MSR CPSR_c, current_flags                 /* Write back */
    }
#else
    /* GNU C inline asm? */
#endif
}

/******************************************************************************
 *
 * FUNCTION:  SYSirq_Enable_Interrupts_Save_Flags
 * PURPOSE:   Enables ARM IRQ and FIQ Interrupts, saves previous
 *            PSR
 *
 ******************************************************************************/
void SYSirq_Enable_Interrupts_Save_Flags(u_int32 *flags)
{
	   #pragma arm
#ifndef __GNUC__
    u_int32 current_flags,my_tmp_flags;
    __asm
    {
	    MRS current_flags, CPSR                 /* Get current CPSR */
        AND my_tmp_flags, current_flags, #0xc0  /* Clear all ex. IRQ and FIQ */
        STR my_tmp_flags, [flags]               /* "save" flags */
        AND current_flags, current_flags, #0x3f /* Enable IRQ and FIQ */
        MSR CPSR_c, current_flags                 /* Write back */
    }
#else
    /* GNU C inline asm? */
#endif
}

/******************************************************************************
 *
 * FUNCTION:  SYSirq_Interrupts_Restore_Flags
 * PURPOSE:   Restores previously saved previous PSR
 *
 ******************************************************************************/
void SYSirq_Interrupts_Restore_Flags(u_int32 flags)
{
	#pragma arm
#ifndef __GNUC__
    u_int32 current_flags;
    __asm
    {
        MRS current_flags, CPSR                 /* Get current CPSR */
        BIC current_flags, current_flags, #0xc0 /* Clear IRQ and FIQ bits */
        ORR current_flags, current_flags, flags /* OR in saved copy */
        MSR CPSR_c, current_flags                 /* Write back */
    }
#else
    /* GNU C inline asm? */
#endif

}




/******************************************************************************
 *
 * FUNCTION:  SYSirq_Initialise
 * PURPOSE:   Initialise Interrupt Requests
 *
 ******************************************************************************/
void SYSirq_Initialise(void)
{
    /*
     * Intialise interrupts
     */
#if (PRH_BS_DEV_USE_DELAYED_SERVICE_ROUTINES == 1)
    dsr_table_head = 0;
    dsr_table_tail = 0;

    pending_dsr_counter = 0;
    dsr_lock = 0;
#endif
    /* SYSirq_IRQ_Disable_All(); - now done in BT_Init */

     /*
      * Install Service Routines
      */
	_SYSirq_Setup_IRQ_FIQ_Enable_Masks();


}




void DataAbort_Exception(void)
{

	while(1)
	{
		//UART_PRINTF("%s \r\n",__func__);
		//uart_putchar("DataAbort_Exception\r\n");
	}

}

#pragma ARM//Ҫ޸ļ
__IRQ__  IRQ_ENTRY void SYSirq_IRQ_Handler(void)
{
    IRQ_Exception();
}

__IRQ__  FIQ_ENTRY void SYSirq_FIQ_Handler(void)
{
    FIQ_Exception();
}

