#include "BK_reg.h"
#include "updata_app.h"
#include "updata_main.h"
#include "updata_driver_flash.h"
#include "updata_driver_uart.h"
#include "updata_driver_wdt.h"

uint8 dm_tx_buff[128];
uint8 jump_flag_buff[4]={0x53,0x53,0X53,0X53};
uint32 all_data_crc32=0xFFFFFFFF;
extern void  updata_memset32(void * dest, uint32 value, uint8 size);


void updata_platform_reset()
{
    void (*pReset)(void);
    // Disable interrupts
    REG_AHB0_ICU_IRQ_ENABLE=0;

    pReset = (void * )(0x0);
    pReset();
}

static uint16 crc16 (uint8 *pD, uint32 len)
{
    uint32 i,j;
    uint8 ds;
    uint16 crc = 0xffff;
    static uint16 poly[2]={0, 0xa001};
    for(j=len; j>0; j--)
    {
        ds = *pD++;
        for(i=0; i<8; i++)
        {
            crc = (crc >> 1) ^ poly[(crc ^ ds ) & 1];
            ds = ds >> 1;
        }
    }
    return crc;
}

uint32 crc32_table[256];
int make_crc32_table(void)
{
    uint32 c;
    int i = 0;
    int bit = 0;
    for(i = 0; i < 256; i++)
    {
        c = (uint32)i;
        for(bit = 0; bit < 8; bit++)
        {
            if(c&1)
            {
                c = (c>>1)^(0xEDB88320);
            }
            else
            {
                c = c >> 1;
            }
        }
        crc32_table[i] = c;

    }
    return 0;
}
uint32 make_crc32(uint32 crc,unsigned char *string,uint32 size)
{
    while(size--)
    {
        crc = (crc >> 8)^(crc32_table[(crc^*string++)&0xff]);
    }
    return crc;
}


void notify_in_updata_mode(void)
{

    uint16 crc;

    dm_tx_buff[0]=0x02;
    dm_tx_buff[1]=0x02;
    dm_tx_buff[2]=0x02;

    dm_tx_buff[3]=DMP_TYPE_NOTIFY;
    dm_tx_buff[4]=NOTIFY_IN_UPDATA_MODE;
    dm_tx_buff[5]=0;
    crc = crc16(&dm_tx_buff[3],3);

    dm_tx_buff[6] = (uint8)(crc&0xFF);
    dm_tx_buff[7] = (uint8)((crc>>8)&0xFF);
    dm_tx_buff[8] = 0x03;
    uart_data_send(&dm_tx_buff[0],9);
}
void notify_flash_erase_status(uint8 status)
{
    uint8 len = 1;
    uint16 crc;

    dm_tx_buff[0]=0x02;
    dm_tx_buff[1]=0x02;
    dm_tx_buff[2]=0x02;

    dm_tx_buff[3]=DMP_TYPE_NOTIFY;
    dm_tx_buff[4]=NOTIFY_FLASH_ERASE_STATUS;
    dm_tx_buff[5]=len;
    dm_tx_buff[6]=status;
    crc = crc16(&dm_tx_buff[3],3+len);
    dm_tx_buff[7] = (uint8)(crc&0xFF);
    dm_tx_buff[8] = (uint8)((crc>>8)&0xFF);
    dm_tx_buff[9] = 0x03;
    uart_data_send(&dm_tx_buff[0],9+len);
}
void notify_flash_write_status(uint8 status)
{
    uint8 len = 1;
    uint16 crc;

    dm_tx_buff[0]=0x02;
    dm_tx_buff[1]=0x02;
    dm_tx_buff[2]=0x02;
    dm_tx_buff[3]=DMP_TYPE_NOTIFY;
    dm_tx_buff[4]=NOTIFY_UPDATA_DATA_STATUS;
    dm_tx_buff[5]=len;
    dm_tx_buff[6]=status;
    crc = crc16(&dm_tx_buff[3],3+len);
    dm_tx_buff[7] = (uint8)(crc&0xFF);
    dm_tx_buff[8] = (uint8)((crc>>8)&0xFF);
    dm_tx_buff[9] = 0x03;
    uart_data_send(&dm_tx_buff[0],9+len);
}
void notify_updata_end_status(uint8 status)
{
    uint8 len = 1;
    uint16 crc;

    dm_tx_buff[0]=0x02;
    dm_tx_buff[1]=0x02;
    dm_tx_buff[2]=0x02;

    dm_tx_buff[3]=DMP_TYPE_NOTIFY;
    dm_tx_buff[4]=NOTIFY_UPDATA_END_STATUS;
    dm_tx_buff[5]=len;
    dm_tx_buff[6]=status;
    crc = crc16(&dm_tx_buff[3],3+len);
    dm_tx_buff[7] = (uint8)(crc&0xFF);
    dm_tx_buff[8] = (uint8)((crc>>8)&0xFF);
    dm_tx_buff[9] = 0x03;
    uart_data_send(&dm_tx_buff[0],9+len);
}
void notify_error_response(uint8 err_code)
{
    uint8 len = 1;
    uint16 crc;

    dm_tx_buff[0]=0x02;
    dm_tx_buff[1]=0x02;
    dm_tx_buff[2]=0x02;

    dm_tx_buff[3]=DMP_TYPE_NOTIFY;
    dm_tx_buff[4]=NOTIFY_ERROR_CODE;
    dm_tx_buff[5]=len;
    dm_tx_buff[6]=err_code;
    crc = crc16(&dm_tx_buff[3],3+len);
    dm_tx_buff[7] = (uint8)(crc&0xFF);
    dm_tx_buff[8] = (uint8)((crc>>8)&0xFF);
    dm_tx_buff[9] = 0x03;
    uart_data_send(&dm_tx_buff[0],9+len);
}



void updata_dmp_cmd_dispath(uint8 *p_data, uint8 len)
{

    uint16 crc = (uint16)((p_data[len-1]<<8)|(p_data[len-2]));
    uint8 err_code = 0;
    uint8 i;
    static uint32 flash_addr;


    //check crc
    if(crc16(p_data, len-sizeof(uint16)/*crc len*/) != crc)
    {
        //err_code = CRC_FAILDED;
    }
    //check cmd type
    if(p_data[DMP_CMD_TYPE_OFFSET]!=DMP_TYPE_CMD)
    {
        err_code = UNRECOGNIZED_COMMAND;
    }
    if(err_code == 0)
    {
        //check package total length
        if(p_data[DMP_CMD_LEN_OFFSET] != (len-DMP_HEADER_LENGTH-sizeof(uint16)/*crc len*/))
        {
            err_code = len;//INVALID_DATA_LENGTH;

        }
        else
        {
            /* package content handle */
            uint8 pack_content_len = p_data[DMP_CMD_LEN_OFFSET];
            uint8 *pack_content = &p_data[DMP_CMD_DATA_OFFSET];
            switch(p_data[DMP_CMD_ID_OFFSET])
            {
                case CMD_SEND_FLASH_ERASE:
                    for(i=0;i<38;i++)
                    {
                        flash_erase_block(FLASH_SPACE_TYPE_MAIN,CODE_START_ADDR+i*0x400);

                    }
                    notify_flash_erase_status(0x01);
                    flash_addr=CODE_START_ADDR;
                    all_data_crc32=0xFFFFFFFF;
                    make_crc32_table();
                    updata_memset32((uint8 *)0x00400008, 0x00, 1);
                    break;

                case CMD_SEND_UPDATAT_DATA:

                    flash_write(FLASH_SPACE_TYPE_MAIN, flash_addr,  pack_content_len,pack_content);
                    flash_addr += pack_content_len/4;
                    all_data_crc32=make_crc32(all_data_crc32,pack_content,pack_content_len);
                    notify_flash_write_status(0x01);

                    break;
                case CMD_SEND_UPDATA_END:
                    if( (pack_content[0]==(all_data_crc32&0xff)) && (pack_content[1]==((all_data_crc32>>8)&0XFF))
                        &&(pack_content[2]==((all_data_crc32>>16)&0XFF)) && (pack_content[3]==((all_data_crc32>>24)&0XFF)))
                    {

                        flash_write(FLASH_SPACE_TYPE_MAIN,JUMP_FLAG_ADDR,4,jump_flag_buff);

                        notify_updata_end_status(0X01);

                        delay_us(5000);
                        updata_memset32((uint8 *)0x00400008, 0x00, 1);

                        delay_us(5000);
                        Driver_wdt_enable(0x10);
                        while(1);
                    }
                    else
                        notify_updata_end_status(0X00);
                    break;
                case CMD_ENTER_UART_UPDATA:
                    notify_in_updata_mode();
                   break;

                default:
                    break;


            }
        }
    }
    if(err_code!=0)
        notify_error_response(err_code);
}


void uart_callback(volatile char * buff, uint16 len)
{
    extern uint8 uart_send_length;
    static uint8 cmd_status=0;//cmd_status_error=0;
    static uint8 index=0;
   // static uint8 cmd_status_error_flag=0;
    static uint8 uart_send_buff[UART_SEND_LENGTH];

    while(len>0)
    {
        switch(cmd_status)
        {
            case UART_CMD_STATE_HEAD_ONE:
            {
                if(buff[0]==0x02)
                    cmd_status=UART_CMD_STATE_HEAD_TWO;
                else
                    cmd_status=UART_CMD_STATE_HEAD_ONE;
            }
            break;
            case UART_CMD_STATE_HEAD_TWO:
            {
                if(buff[0]==0x02)
                    cmd_status=UART_CMD_STATE_HEAD_THREE;
                else
                    cmd_status=UART_CMD_STATE_HEAD_ONE;
            }
            break;
            case UART_CMD_STATE_HEAD_THREE:
            {
                if(buff[0]==0x02)
                    cmd_status=UART_CMD_STATE_HEAD_FOUR;
                else
                    cmd_status=UART_CMD_STATE_HEAD_ONE;
            }
            break;
            case UART_CMD_STATE_HEAD_FOUR:
            {
                if(buff[0]==0x01)
                {
                    cmd_status=UART_CMD_STATE_OPCODE;
                    uart_send_buff[0]=buff[0];

                }
                else
                    cmd_status=UART_CMD_STATE_HEAD_ONE;
            }
            break;
            case UART_CMD_STATE_OPCODE:
            {
                    uart_send_buff[1]=buff[0];
                    cmd_status=UART_CMD_STATE_LENGTH;
                    index=0;
                    //current_clk = HW_Get_Native_Clk_Avoid_Race();
            }
            break;
            case UART_CMD_STATE_LENGTH:
            {
                    //last_clk=current_clk;
                    //current_clk = HW_Get_Native_Clk_Avoid_Race();

                    uart_send_buff[2+index]=buff[0];

                    if(index==uart_send_buff[2]+3)
                    {

                        if(buff[0]==0x03)
                        {

                            cmd_status=UART_CMD_STATE_HEAD_ONE;
                            uart_send_length=uart_send_buff[2]+5;
                            updata_dmp_cmd_dispath(uart_send_buff, uart_send_length);
                            //sys_flag &= ~FLAG_UART_INTERRPUT;

                        }
                    }
                    else if(uart_send_buff[2]>0x80)
                        cmd_status=UART_CMD_STATE_HEAD_ONE;



                    index++;

            }
            break;
        }
        len--;
        buff++;
    }
}



void Device_uart_rx(void)
{
    extern volatile uint16 uart_rx_buff_header,uart_rx_buff_tailor;
    extern volatile char uart_rx_tx_buff[UART_BUFF_LEN];

    static uint16 uart_rx_buff_temp;
    //static uint8 uart_rx_buff_cnt=0;

    uart_rx_buff_temp=uart_rx_buff_header;
    if (uart_rx_buff_tailor < uart_rx_buff_temp)
    {
        uart_callback(uart_rx_tx_buff + uart_rx_buff_tailor, uart_rx_buff_temp - uart_rx_buff_tailor);
        uart_rx_buff_tailor = uart_rx_buff_temp;
        //uart_rx_buff_cnt=0;
    }
    else if (uart_rx_buff_tailor > uart_rx_buff_temp)
    {
        uart_callback(uart_rx_tx_buff + uart_rx_buff_tailor, sizeof(uart_rx_tx_buff) - uart_rx_buff_tailor);
        uart_callback(uart_rx_tx_buff, uart_rx_buff_temp);
        uart_rx_buff_tailor = uart_rx_buff_temp;
        //uart_rx_buff_cnt=0;
    }

}


