
#include "BK_reg.h"
#include "updata_main.h"
#include "updata_driver_flash.h"


/// Specific to EMBED BEKEN FLASH  (type 1)
#define FLASH_SECT_SIZE1         0x00000200  //  512 Byte
#define FLASH_SECT_SIZE2         0x00001000  //  4 KByte
#define FLASH_BOUNDARY256B       0x00000100  // 256 Byte



/// Flash environment structure
struct flash_env_tag
{
    unsigned int    length[2];
   
    unsigned char     space_type[2];
};


static struct flash_env_tag flash_env;


void updata_delay_ms(unsigned int tt)
{
    unsigned int i,j;
    while(tt--)
    {
        for (j=0; j<1000; j++)
        {
            for (i=0; i<12; i++)
            {
                ;
            }
        }
    }
}


static void flash_unlock(void)
{
    // Unlock all sectors
    REG_AHB3_MFC_WP0 = 0xA5;
    REG_AHB3_MFC_WP1 = 0xC3;
}
 
static void flash_writeKey(void)
{
    // write control key
    REG_AHB3_MFC_KEYWORD = 0x58A9;
    REG_AHB3_MFC_KEYWORD = 0xA958;
}

static void flash_clearKey(void)
{
    // write control key
    REG_AHB3_MFC_KEYWORD = 0x0;
    REG_AHB3_MFC_KEYWORD = 0x0;
}
 
static void flash_start(void)
{
    REG_AHB3_MFC_CONTROL |= 0x01;
}

static uint8 flash_status(void)
{
    return REG_AHB3_MFC_CONTROL & 0x01;
}

 void flash_init(void)
 {
     // Init flash environment    
     flash_env.length[0]    =  FLASH_MAIN_SIZE;
     flash_env.space_type[0]  = FLASH_SPACE_TYPE_MAIN; 
     
     flash_env.length[1]    =  FLASH_NVR_SIZE;
     flash_env.space_type[1]  = FLASH_SPACE_TYPE_NVR;
  
 }
 

 uint32 flash_readword(uint8 type,uint32 address)
{
    uint32 reg;
    uint32 data;
    

    REG_AHB3_MFC_ADDR = address;

    flash_writeKey(); // write key
    flash_unlock(); //wipe off WP

    reg = REG_AHB3_MFC_CONTROL;
    reg &= ~((0x07 << 2) | (0x03 << 5)); //clear control mode and space
    reg  |= ( MFC_CONTROL_READ | (type << 5)); // set write mode and control space
    REG_AHB3_MFC_CONTROL = reg;

    flash_start();

    while(flash_status() == 1);

    data = REG_AHB3_MFC_DATA;
    flash_clearKey();
    return data;
}

 void flash_writeword(uint8 type,uint32 address, uint32 data)
{
    uint32 reg;
   
    REG_AHB3_MFC_ADDR = address;
    /* Write the data                                                                   */
    REG_AHB3_MFC_DATA = data;
    flash_writeKey(); // write key
    flash_unlock(); //wipe off WP
    reg = REG_AHB3_MFC_CONTROL;
    reg &= ~((0x07 << 2) | (0x03 << 5)); //clear control mode and space
    reg  |= ( MFC_CONTROL_WRITE | (type << 5)); // set write mode and control space
    REG_AHB3_MFC_CONTROL = reg;
    flash_start();
    while(flash_status()) ;
    flash_clearKey();
	
}

void flash_erase_sector(uint8 type,uint32 address)
{

    uint32 reg;

    REG_AHB3_MFC_ADDR = address;

    flash_writeKey(); // write key
    flash_unlock(); //wipe off WP

    reg = REG_AHB3_MFC_CONTROL;
    reg &= ~((0x07 << 2) | (0x03 << 5)); //clear control mode and space
    reg  |= ( MFC_CONTROL_SECT_ERASE| (type << 5)); // set write mode and control space
    REG_AHB3_MFC_CONTROL = reg;

    flash_start();
    //UPDATA_DEBUG_MSG(0Xd1);
    while(flash_status());
    //updata_delay_ms(20);
    //UPDATA_DEBUG_MSG(0Xd2);
    flash_clearKey();
    
    //UPDATA_DEBUG_MSG(0Xd3);
}

void flash_erase_block(uint8 type,uint32 address)
{
    uint32 reg;

    REG_AHB3_MFC_ADDR = address;

    flash_writeKey(); // write key   
    flash_unlock(); //wipe off WP
    
    reg = REG_AHB3_MFC_CONTROL;
    reg &= ~((0x07 << 2) | (0x03 << 5)); //clear control mode and space
    reg  |= ( MFC_CONTROL_BLOCK_ERASE | (type << 5)); // set write mode and control space
    REG_AHB3_MFC_CONTROL = reg;

    flash_start();    
    while(flash_status());
   
    flash_clearKey();
    
    
}




void flash_write(uint8 flash_space, uint32 address, uint32 length, uint8 *buffer)
{
    uint32 data = 0xffffffff;

    uint8  cnt;
   
    // Check parameters
    if ( (flash_space > FLASH_SPACE_TYPE_NVR) || (( length) > flash_env.length[flash_space]) )
    {
        return ;
    }

    while(length >= 4)
    {
        data = (buffer[0] | (buffer[1] << 8) | (buffer[2] << 16) | (buffer[3] << 24)); 
        
        flash_writeword(flash_space,address , data);

        address += 1;
        buffer += 4;
        length -= 4;
        //bprintf("Data = %x length = %x\r\n",data,length);
    }

    if(length != 0)
    { /* write last mutil byte */
        data = 0xffffffff;
				
        for(cnt = 0; cnt < length;cnt++)
        {
            data &= ~(0xff << (8 * cnt));
            data |= (buffer[cnt] << (8 * cnt )) ;
        }

        flash_writeword(flash_space,address, data);
        //	uart_printf("Data2 = 0x%08x length = %d\r\n",Data,length);
    }

    return ;
}

void flash_read(uint8 flash_space, uint32 address, uint32 length, uint8 *buffer)
{
    uint32 data = 0xffffffff;

    uint8 cnt;

   
    
    // Check parameters
    if (  length > flash_env.length[flash_space] )
    {        
        return ;
    }

    if ( flash_space > FLASH_SPACE_TYPE_NVR )
    {        
        return ;
    }


    while(length >= 4)
    {
			
        data = flash_readword(flash_space,address);
		//bprintf("read data0 = %x\r\n",data);		
        memcpy(buffer, &data, 4);
        address += 1;
        buffer += 4;
        length -= 4;
    }

    if(length != 0)
    {
				
        /* read last byte */
        data = flash_readword(flash_space,address);

        for(cnt = 0; cnt < length;cnt++)
        {
            *buffer++ = ( data >> (cnt  * 8) & 0xFF );
        }

    }

    return ;
}



